@@ -76,13 +76,13 @@ class Graph(dict):
         ## Then we get the values from the database
         cr.execute('SELECT name, id, state, demo AS dbdemo, latest_version AS installed_version'
                    '  FROM ir_module_module'
-                   ' WHERE name in (%s)' % (','.join(['%s'] * len(self))),
-                    additional_data.keys()
+                   ' WHERE name in %s',
+                    (tuple(additional_data),)
                    )
 
         ## and we update the default values with values from the database
         additional_data.update(dict([(x.pop('name'), x) for x in cr.dictfetchall()]))
-
+        
         for package in self.values():
             for k, v in additional_data[package.name].items():
                 setattr(package, k, v)
@@ -311,7 +311,7 @@ def upgrade_graph(graph, cr, module_list, force=None):
         mod_path = get_module_path(module)
         terp_file = get_module_resource(module, '__terp__.py')
         if not mod_path or not terp_file:
-            cr.execute("update ir_module_module set state=%s where name=%s", ('uninstallable', module))
+            #Removed the query which was setting the module state uninstallable if module is not found
             continue
 
         if os.path.isfile(terp_file) or zipfile.is_zipfile(mod_path+'.zip'):
@@ -363,7 +363,10 @@ def init_module_objects(cr, module_name, obj_list):
     logger.notifyChannel('init', netsvc.LOG_INFO, 'module %s: creating or updating database tables' % module_name)
     todo = []
     for obj in obj_list:
-        result = obj._auto_init(cr, {'module': module_name})
+        try:
+            result = obj._auto_init(cr, {'module': module_name})
+        except Exception, e:
+            raise 
         if result:
             todo += result
         if hasattr(obj, 'init'):
@@ -602,6 +605,16 @@ def load_module_graph(cr, graph, status=None, perform_checks=True, **kwargs):
         if hasattr(package, 'init') or hasattr(package, 'update') or package.state in ('to install', 'to upgrade'):
             has_updates = True
             for kind in ('init', 'update'):
+                if package.state=='to upgrade':
+                    # upgrading the module information
+                    modobj.write(cr, 1, [mid], {
+                    'description': package.data.get('description', ''),
+                    'shortdesc': package.data.get('name', ''),
+                    'author': package.data.get('author', 'Unknown'),
+                    'website': package.data.get('website', ''),
+                    'license': package.data.get('license', 'GPL-2'),
+                    'certificate': package.data.get('certificate') or None,
+                    })
                 for filename in package.data.get('%s_xml' % kind, []):
                     logger.notifyChannel('init', netsvc.LOG_INFO, 'module %s: loading %s' % (m, filename))
                     name, ext = os.path.splitext(filename)
@@ -668,7 +681,6 @@ def load_modules(db, force_demo=False, status=None, update_module=False):
        if len(cr.fetchall())==0:    
            logger.notifyChannel("init", netsvc.LOG_INFO, "init db")
            tools.init_db(cr)
-#           cr.execute("update res_users set password=%s where id=%s",('admin',1))
            # in that case, force --init=all
            tools.config["init"]["all"] = 1
            tools.config['update']['all'] = 1
@@ -713,7 +725,9 @@ def load_modules(db, force_demo=False, status=None, update_module=False):
             loop_guardrail += 1
             if loop_guardrail > 100:
                 raise ProgrammingError()
-            cr.execute("SELECT name from ir_module_module WHERE state in (%s)" % ','.join(['%s']*len(STATES_TO_LOAD)), STATES_TO_LOAD)
+            cr.execute("SELECT name from ir_module_module WHERE state in %s",
+                       (tuple(STATES_TO_LOAD),)
+                      )
 
             module_list = [name for (name,) in cr.fetchall() if name not in graph]
             if not module_list:
@@ -723,7 +737,6 @@ def load_modules(db, force_demo=False, status=None, update_module=False):
             if new_modules_in_graph == 0:
                 # nothing to load
                 break
-
             logger.notifyChannel('init', netsvc.LOG_DEBUG, 'Updating graph with %d more modules' % (len(module_list)))
             r = load_module_graph(cr, graph, status, report=report)
             has_updates = has_updates or r
