@@ -19,7 +19,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################
-
+from operator import itemgetter
 import pooler
 import time
 from report import report_sxw
@@ -29,7 +29,7 @@ from report import report_sxw
 #
 class journal_print(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(journal_print, self).__init__(cr, uid, name, context)
+        super(journal_print, self).__init__(cr, uid, name, context=context)
         self.localcontext.update( {
             'time': time,
             'lines': self.lines,
@@ -42,10 +42,12 @@ class journal_print(report_sxw.rml_parse):
 
     def set_context(self, objects, data, ids, report_type = None):
         super(journal_print, self).set_context(objects, data, ids, report_type)
-        self.cr.execute('select period_id, journal_id from account_journal_period where id in (' + ','.join([str(id) for id in ids]) + ')')
+        self.cr.execute('SELECT period_id, journal_id '
+                        'FROM account_journal_period '
+                        'WHERE id IN %s',
+                        (tuple(ids),))
         res = self.cr.fetchall()
-        self.period_ids = ','.join([str(x[0]) for x in res])
-        self.journal_ids = ','.join([str(x[1]) for x in res])
+        self.period_ids, self.journal_ids = zip(*res)
 
     # returns a list of period objs
     def periods(self, journal_period_objs):
@@ -75,7 +77,14 @@ class journal_print(report_sxw.rml_parse):
                     periods.append(data.period_id.id)
             for period in periods:
                 period_data = self.pool.get('account.period').browse(self.cr, self.uid, period)
-                self.cr.execute('select j.code, j.name, sum(l.debit) as debit, sum(l.credit) as credit from account_move_line l left join account_journal j on (l.journal_id=j.id) where period_id=%s and journal_id in (' + ','.join(map(str, journal_id)) + ') and l.state<>\'draft\' group by j.id, j.code, j.name', (period,))
+                self.cr.execute(
+                    'SELECT j.code, j.name, '
+                    'SUM(l.debit) AS debit, SUM(l.credit) AS credit '
+                    'FROM account_move_line l '
+                    'LEFT JOIN account_journal j ON (l.journal_id=j.id) '
+                    'WHERE period_id=%s AND journal_id IN %s '
+                    'AND l.state<>\'draft\' '
+                    'GROUP BY j.id, j.code, j.name', (period, tuple(journal_id)))
                 res = self.cr.dictfetchall()
                 res[0].update({'period_name':period_data.name})
                 res[0].update({'pid':period})
@@ -83,45 +92,59 @@ class journal_print(report_sxw.rml_parse):
             return lines_data
         if not self.journal_ids:
             return []
-        self.cr.execute('select j.code, j.name, sum(l.debit) as debit, sum(l.credit) as credit from account_move_line l left join account_journal j on (l.journal_id=j.id) where period_id=%s and journal_id in (' + self.journal_ids + ') and l.state<>\'draft\' group by j.id, j.code, j.name', (period_id,))
+        self.cr.execute('SELECT j.code, j.name, '
+                        'SUM(l.debit) AS debit, SUM(l.credit) AS credit '
+                        'FROM account_move_line l '
+                        'LEFT JOIN account_journal j ON (l.journal_id=j.id) '
+                        'WHERE period_id=%s AND journal_id IN %s '
+                        'AND l.state<>\'draft\' '
+                        'GROUP BY j.id, j.code, j.name'
+                        (period_id,tuple(self.journal_ids)))
         res = self.cr.dictfetchall()
         return res
 
     def _sum_debit_period(self, period_id,journal_id=None):
-        if type(journal_id)==type([]):
-            self.cr.execute('select sum(debit) from account_move_line where period_id=%s and journal_id in (' + ','.join(map(str, journal_id)) + ') and state<>\'draft\'', (period_id,))
-            return self.cr.fetchone()[0] or 0.0
-        if not self.journal_ids:
+        journals = journal_id or self.journal_ids
+        if not journals:
             return 0.0
-        self.cr.execute('select sum(debit) from account_move_line where period_id=%s and journal_id in (' + self.journal_ids + ') and state<>\'draft\'', (period_id,))
-
+        self.cr.execute('SELECT SUM(debit) FROM account_move_line '
+                        'WHERE period_id=%s AND journal_id IN %s '
+                        'AND state<>\'draft\'',
+                        (period_id, tuple(journals)))
         return self.cr.fetchone()[0] or 0.0
 
     def _sum_credit_period(self, period_id,journal_id=None):
-        if type(journal_id)==type([]):
-            self.cr.execute('select sum(credit) from account_move_line where period_id=%s and journal_id in (' + ','.join(map(str, journal_id)) + ') and state<>\'draft\'', (period_id,))
-            return self.cr.fetchone()[0] or 0.0
-        if not self.journal_ids:
+        journals = journal_id or self.journal_ids
+        if not journals:
             return 0.0
-        self.cr.execute('select sum(credit) from account_move_line where period_id=%s and journal_id in (' + self.journal_ids + ') and state<>\'draft\'', (period_id,))
+        self.cr.execute('SELECT SUM(credit) FROM account_move_line '
+                        'WHERE period_id=%s AND journal_id IN %s '
+                        'AND state<>\'draft\'',
+                        (period_id,tuple(journals)))
         return self.cr.fetchone()[0] or 0.0
 
     def _sum_debit(self,period_id=None,journal_id=None):
-        if type(period_id)==type([]):
-            self.cr.execute('select sum(debit) from account_move_line where period_id in (' + ','.join(map(str, period_id)) + ') and journal_id in (' + ','.join(map(str, journal_id)) + ') and state<>\'draft\'')
-            return self.cr.fetchone()[0] or 0.0
-        if not self.journal_ids or not self.period_ids:
+        journals = journal_id or self.journal_ids
+        periods = period_id or self.period_ids
+        if not (journals and periods):
             return 0.0
-        self.cr.execute('select sum(debit) from account_move_line where period_id in (' + self.period_ids + ') and journal_id in (' + self.journal_ids + ') and state<>\'draft\'')
+        self.cr.execute('SELECT SUM(debit) FROM account_move_line '
+                        'WHERE period_id IN %s '
+                        'AND journal_id IN %s '
+                        'AND state<>\'draft\'',
+                        (tuple(periods), tuple(journals)))
         return self.cr.fetchone()[0] or 0.0
 
     def _sum_credit(self,period_id=None,journal_id=None):
-        if type(period_id)==type([]):
-            self.cr.execute('select sum(credit) from account_move_line where period_id in (' + ','.join(map(str, period_id)) + ') and journal_id in (' + ','.join(map(str, journal_id)) + ') and state<>\'draft\'')
-            return self.cr.fetchone()[0] or 0.0
-        if not self.journal_ids or not self.period_ids:
+        periods = period_id or self.period_ids
+        journals = journal_id or self.journal_ids
+        if not (periods and journals):
             return 0.0
-        self.cr.execute('select sum(credit) from account_move_line where period_id in (' + self.period_ids + ') and journal_id in (' + self.journal_ids + ') and state<>\'draft\'')
+        self.cr.execute('SELECT SUM(credit) FROM account_move_line '
+                        'WHERE period_id IN %s '
+                        'AND journal_id IN %s '
+                        'AND state<>\'draft\'',
+                        (tuple(periods), tuple(journals)))
         return self.cr.fetchone()[0] or 0.0
 report_sxw.report_sxw('report.account.general.journal', 'account.journal.period', 'addons/account/report/general_journal.rml',parser=journal_print)
 report_sxw.report_sxw('report.account.general.journal.wiz', 'account.journal.period', 'addons/account/report/wizard_general_journal.rml',parser=journal_print, header=False)
