@@ -53,7 +53,7 @@ class general_ledger(rml_parse.rml_parse):
         super(general_ledger, self).set_context(objects, data, new_ids, report_type)
 
     def __init__(self, cr, uid, name, context):
-        super(general_ledger, self).__init__(cr, uid, name, context)
+        super(general_ledger, self).__init__(cr, uid, name, context=context)
         self.date_borne = {}
         self.query = ""
         self.child_ids = ""
@@ -123,14 +123,15 @@ class general_ledger(rml_parse.rml_parse):
             periods = form['periods'][0][2]
             if not periods:
                 sql = """
-                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.fiscalyear_id = """ + str(form['fiscalyear'])   + """
+                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.fiscalyear_id = %s
                     """
+                sqlargs = (form['fiscalyear'],)
             else:
-                periods_id = ','.join(map(str, periods))
                 sql = """
-                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.id in ( """ + periods_id   + """)
+                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.id in %s
                     """
-            self.cr.execute(sql)
+                sqlargs = (tuple(periods),)
+            self.cr.execute(sql, sqlargs)
             res = self.cr.dictfetchall()
             borne_min = res[0]['start_date']
             borne_max = res[0]['stop_date']
@@ -141,14 +142,21 @@ class general_ledger(rml_parse.rml_parse):
             periods = form['periods'][0][2]
             if not periods:
                 sql = """
-                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.fiscalyear_id = """ + str(form['fiscalyear'])   + """
+                    SELECT MIN(p.date_start) AS start_date,
+                           MAX(p.date_stop) AS stop_date
+                    FROM account_period AS p
+                    WHERE p.fiscalyear_id = %s
                     """
+                sqlargs = (form['fiscalyear'],)
             else:
-                periods_id = ','.join(map(str, periods))
                 sql = """
-                    Select min(p.date_start) as start_date,max(p.date_stop) as stop_date from account_period as p where p.id in ( """ + periods_id   + """)
+                    SELECT MIN(p.date_start) AS start_date,
+                           MAX(p.date_stop) AS stop_date
+                    FROM account_period AS p
+                    WHERE p.id IN %s
                     """
-            self.cr.execute(sql)
+                sqlargs = (tuple(periods),)
+            self.cr.execute(sql, sqlargs)
             res = self.cr.dictfetchall()
             period_min = res[0]['start_date']
             period_max = res[0]['stop_date']
@@ -232,8 +240,12 @@ class general_ledger(rml_parse.rml_parse):
         else:
             ## We will now compute solde initiaux
             for move in res:
-                SOLDEINIT = "SELECT sum(l.debit) AS sum_debit, sum(l.credit) AS sum_credit FROM account_move_line l WHERE l.account_id = " + str(move.id) +  " AND l.date < '" + self.borne_date['max_date'] + "'" +  " AND l.date > '" + self.borne_date['min_date'] + "'"
-                self.cr.execute(SOLDEINIT)
+                SOLDEINIT = "SELECT SUM(l.debit) AS sum_debit,"\
+                            "       SUM(l.credit) AS sum_credit "\
+                            "FROM account_move_line l "\
+                            "WHERE l.account_id = %s "\
+                            "AND l.date < %s AND l.date > %s"
+                self.cr.execute(SOLDEINIT, (move.id, self.borne_date['max_date'],self.borne_date['min_date']))
                 resultat = self.cr.dictfetchall()
                 if resultat[0] :
                     if resultat[0]['sum_debit'] == None:
@@ -268,7 +280,7 @@ class general_ledger(rml_parse.rml_parse):
         else:
             sorttag = 'j.code'
         sql = """
-            SELECT l.id, l.date, j.code,c.code AS currency_code,l.amount_currency,l.ref, l.name , l.debit, l.credit, l.period_id
+            SELECT l.id, l.date, j.code,c.code AS currency_code,l.amount_currency,l.ref, l.name , COALESCE(l.debit,0) as debit, COALESCE(l.credit,0) as credit, l.period_id
                     FROM account_move_line as l
                        LEFT JOIN res_currency c on (l.currency_id=c.id)
                           JOIN account_journal j on (l.journal_id=j.id)
@@ -354,7 +366,8 @@ class general_ledger(rml_parse.rml_parse):
             return 0.0
         self.cr.execute("SELECT sum(debit) "\
                 "FROM account_move_line l "\
-                "WHERE l.account_id in ("+','.join(map(str, self.child_ids))+") AND "+self.query)
+                "WHERE l.account_id in %s AND "+self.query,
+                        (tuple(self.child_ids),))
         sum_debit = self.cr.fetchone()[0] or 0.0
         return sum_debit
 
@@ -363,7 +376,8 @@ class general_ledger(rml_parse.rml_parse):
             return 0.0
         self.cr.execute("SELECT sum(credit) "\
                 "FROM account_move_line l "\
-                "WHERE l.account_id in ("+','.join(map(str, self.child_ids))+") AND "+self.query)
+                "WHERE l.account_id in %s AND "+self.query,
+                        (tuple(self.child_ids),))
         ## Add solde init to the result
         #
         sum_credit = self.cr.fetchone()[0] or 0.0
@@ -374,7 +388,8 @@ class general_ledger(rml_parse.rml_parse):
             return 0.0
         self.cr.execute("SELECT (sum(debit) - sum(credit)) as tot_solde "\
                 "FROM account_move_line l "\
-                "WHERE l.account_id in ("+','.join(map(str, self.child_ids))+") AND "+self.query)
+                "WHERE l.account_id in %s AND "+self.query,
+                        (tuple(self.child_ids),))
         sum_solde = self.cr.fetchone()[0] or 0.0
         return sum_solde
 
