@@ -57,10 +57,10 @@ def _data_save(self, cr, uid, data, context):
 
     fy_id = data['form']['fy_id']
     period_ids = pool.get('account.period').search(cr, uid, [('fiscalyear_id', '=', fy_id)])
-    fy_period_set = ','.join(map(str, period_ids))
-    periods_fy2 = pool.get('account.period').search(cr, uid, [('fiscalyear_id', '=', data['form']['fy2_id'])])
-    fy2_period_set = ','.join(map(str, periods_fy2))
-
+    cr.execute("SELECT id FROM account_period WHERE date_stop < (SELECT date_start FROM account_fiscalyear WHERE id = %s)" , (str(data['form']['fy2_id']),))
+    fy_period_set = ','.join(map(lambda id: str(id[0]), cr.fetchall()))
+    cr.execute("SELECT id FROM account_period WHERE date_start > (SELECT date_stop FROM account_fiscalyear WHERE id = %s)" , (str(fy_id),))
+    fy2_period_set = ','.join(map(lambda id: str(id[0]), cr.fetchall()))
     period = pool.get('account.period').browse(cr, uid, data['form']['period_id'], context=context)
     new_fyear = pool.get('account.fiscalyear').browse(cr, uid, data['form']['fy2_id'], context=context)
     old_fyear = pool.get('account.fiscalyear').browse(cr, uid, data['form']['fy_id'], context=context)
@@ -80,10 +80,11 @@ def _data_save(self, cr, uid, data, context):
     if move_ids:
         raise wizard.except_wizard(_('UserError'),
                 _('The opening journal must not have any entry in the new fiscal year !'))
-
-
+    cr.execute("SELECT id FROM account_fiscalyear WHERE date_stop < %s", (str(new_fyear.date_start),))
+    result = cr.dictfetchall()
+    fy_ids = ','.join([str(x['id']) for x in result])
     query_line = pool.get('account.move.line')._query_get(cr, uid,
-            obj='account_move_line', context={'fiscalyear': fy_id})
+            obj='account_move_line', context={'fiscalyear': fy_ids})
     cr.execute('select id from account_account WHERE active')
     ids = map(lambda x: x[0], cr.fetchall())
     for account in pool.get('account.account').browse(cr, uid, ids,
@@ -139,9 +140,7 @@ def _data_save(self, cr, uid, data, context):
             offset = 0
             limit = 100
             while True:
-                #TODO: this query could be improved in order to work if there is more than 2 open FY
-                # a.period_id IN ('+fy2_period_set+') is the problematic clause
-                cr.execute('SELECT b.id, b.name, b.quantity, b.debit, b.credit, b.account_id, b.ref, ' \
+                cr.execute('SELECT DISTINCT b.id, b.name, b.quantity, b.debit, b.credit, b.account_id, b.ref, ' \
                             'b.amount_currency, b.currency_id, b.blocked, b.partner_id, ' \
                             'b.date_maturity, b.date_created ' \
                         'FROM account_move_line a, account_move_line b ' \
