@@ -106,8 +106,8 @@ def _check(self, cr, uid, data, context):
 def _check_date(self, cr, uid, data, context):
     
     sql = """
-        SELECT f.id, f.date_start, f.date_stop FROM account_fiscalyear f  Where '%s' between f.date_start and f.date_stop """%(data['form']['date_from'])
-    cr.execute(sql)
+        SELECT f.id, f.date_start, f.date_stop FROM account_fiscalyear f  Where %s between f.date_start and f.date_stop """
+    cr.execute(sql, (data['form']['date_from'],))
     res = cr.dictfetchall()
     if res:
         if (data['form']['date_to'] > res[0]['date_stop'] or data['form']['date_to'] < res[0]['date_start']):
