@@ -36,7 +36,7 @@ sur_form = '''<?xml version="1.0"?>
 </form>'''
 
 sur_fields = {
-    'date': {'string':'Operation date','type':'date', 'required':'False'},
+    'date': {'string':'Operation date','type':'date', 'required':'False', 'default':time.strftime('%Y-%m-%d'), 'help' : 'This date will be used as the invoice date for Refund Invoice and Period will be chosen accordingly!'},
     'period':{'string': 'Force period', 'type': 'many2one',
         'relation': 'account.period', 'required': False},
     'description':{'string':'Description', 'type':'char', 'required':'True'},
@@ -110,7 +110,9 @@ class wiz_refund(wizard.interface):
             # we compute due date
             #!!!due date = date inv date on formdate
             pool.get('account.invoice').write(cr, uid, [refund.id],{'date_due':date,'check_total':inv.check_total})
-
+            # to make the taxes calculated
+            pool.get('account.invoice').button_compute(cr, uid, refund_id)
+            
             created_inv.append(refund_id[0])
             #if inv is paid we unreconcile
             if mode in ('cancel','modify'):
@@ -152,10 +154,10 @@ class wiz_refund(wizard.interface):
                     invoice = invoice[0]
                     del invoice['id']
                     invoice_lines = pool.get('account.invoice.line').read(cr, uid, invoice['invoice_line'])
-                    invoice_lines = pool.get('account.invoice')._refund_cleanup_lines(invoice_lines)
+                    invoice_lines = pool.get('account.invoice')._refund_cleanup_lines(cr, uid, invoice_lines)
                     tax_lines = pool.get('account.invoice.tax').read(
                         cr, uid, invoice['tax_line'])
-                    tax_lines = pool.get('account.invoice')._refund_cleanup_lines(tax_lines)
+                    tax_lines = pool.get('account.invoice')._refund_cleanup_lines(cr, uid, tax_lines)
 
                     invoice.update({
                         'type': inv.type,
@@ -189,7 +191,7 @@ class wiz_refund(wizard.interface):
             xml_id = 'action_invoice_tree5'
         elif inv.type == 'in_invoice':
             xml_id = 'action_invoice_tree8'
-        elif type == 'out_refund':
+        elif inv.type == 'out_refund':
             xml_id = 'action_invoice_tree10'
         else:
             xml_id = 'action_invoice_tree12'
