@@ -19,7 +19,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################
-from xml import dom
+from lxml import etree
 
 from mx import DateTime
 from mx.DateTime import now
@@ -163,7 +163,7 @@ class account_analytic_plan_instance(osv.osv):
                 <newline/>"""%(i,tools.to_xml(line.name),tools.to_xml(line.name),line.root_analytic_id and line.root_analytic_id.id or 0)
                     i+=1
                 res['arch'] += "</form>"
-                doc = dom.minidom.parseString(res['arch'])
+                doc = etree.fromstring(res['arch'].encode('utf8'))
                 xarch, xfields = self._view_look_dom_arch(cr, uid, doc, view_id, context=context)
                 res['arch'] = xarch
                 res['fields'] = xfields
@@ -283,14 +283,15 @@ class account_move_line(osv.osv):
 
     def create_analytic_lines(self, cr, uid, ids, context={}):
         super(account_move_line, self).create_analytic_lines(cr, uid, ids, context)
+        analytic_line_obj = self.pool.get('account.analytic.line')
         for line in self.browse(cr, uid, ids, context):
            if line.analytics_id:
-               toremove = self.pool.get('account.analytic.line').search(cr, uid, [('move_id','=',line.id)], context=context)
+               toremove = analytic_line_obj.search(cr, uid, [('move_id','=',line.id)], context=context)
                if toremove:
-                    line.unlink(cr, uid, toremove, context=context)
+                    analytic_line_obj.unlink(cr, uid, toremove, context=context)
                for line2 in line.analytics_id.account_ids:
                    val = (line.credit or  0.0) - (line.debit or 0.0)
-                   amt=val * (line2.rate/100)
+                   amt = val * (line2.rate/100)
                    al_vals={
                        'name': line.name,
                        'date': line.date,
@@ -304,7 +305,7 @@ class account_move_line(osv.osv):
                        'journal_id': line.analytics_id.journal_id.id,
                        'ref': line.ref,
                    }
-                   ali_id=self.pool.get('account.analytic.line').create(cr,uid,al_vals)
+                   ali_id = analytic_line_obj.create(cr, uid, al_vals, context=context)
         return True
 
 account_move_line()
@@ -375,4 +376,25 @@ class analytic_default(osv.osv):
     }
 analytic_default()
 
+class sale_order_line(osv.osv):
+    _inherit = 'sale.order.line'
+
+    # Method overridden to set the analytic account by default on criterion match
+    def invoice_line_create(self, cr, uid, ids, context={}):
+        create_ids = super(sale_order_line,self).invoice_line_create(cr, uid, ids, context)
+        if ids:
+            sale_line_obj = self.browse(cr, uid, ids[0], context)
+            pool_inv_line = self.pool.get('account.invoice.line')
+
+            for line in pool_inv_line.browse(cr, uid, create_ids, context):
+                rec = self.pool.get('account.analytic.default').account_get(cr, uid, line.product_id.id, sale_line_obj.order_id.partner_id.id, uid, time.strftime('%Y-%m-%d'), context)
+
+                if rec:
+                    pool_inv_line.write(cr, uid, [line.id], {'analytics_id':rec.analytics_id.id}, context=context)
+                    cr.commit()
+        return create_ids
+
+sale_order_line()
+
+
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
