@@ -25,7 +25,7 @@ from report import report_sxw
 
 class account_invoice_1(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(account_invoice_1, self).__init__(cr, uid, name, context)
+        super(account_invoice_1, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
             'invoice_lines': self.invoice_lines,
