@@ -26,7 +26,7 @@ import pooler
 
 class account_invoice_with_message(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(account_invoice_with_message, self).__init__(cr, uid, name, context)
+        super(account_invoice_with_message, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
             'spcl_msg': self.spcl_msg,
@@ -132,14 +132,14 @@ class account_invoice_with_message(report_sxw.rml_parse):
                     res['price_subtotal']=''
                     res['currency']=''
                 elif entry.state=='line':
-                    res['quantity']='___________________'
-                    res['price_unit']='______________________'
-                    res['discount']='____________________________________'
-                    res['tax_types']='_____________________'
+                    res['quantity']='_______________'
+                    res['price_unit']='______________'
+                    res['discount']='____________'
+                    res['tax_types']='____________________'
                     res['uos']='_____'
-                    res['name']='______________________________________'
-                    res['price_subtotal']='___________'
-                    res['currency']='_'
+                    res['name']='_______________________________________________'
+                    res['price_subtotal']='____________'
+                    res['currency']='____'
                 elif entry.state=='break':
                     res['type']=entry.state
                     res['name']=entry.name
