@@ -26,7 +26,7 @@ from report import report_sxw
 
 class payment_order(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(payment_order, self).__init__(cr, uid, name, context)
+        super(payment_order, self).__init__(cr, uid, name, context=context)
         self.localcontext.update( {
             'time': time,
 
