@@ -36,7 +36,7 @@ parents = {
 
 class account_report_bs(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(account_report_bs, self).__init__(cr, uid, name, context)
+        super(account_report_bs, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
             'lines': self.lines,
