@@ -24,6 +24,7 @@ import time
 import netsvc
 from osv import fields, osv
 import ir
+from tools import config
 
 class account_invoice(osv.osv):
     _inherit = "account.invoice"
@@ -36,6 +37,20 @@ class account_invoice(osv.osv):
     _defaults = {
         'price_type': lambda *a: 'tax_excluded',
     }
+    
+    def refund(self, cr, uid, ids, date=None, period_id=None, description=None):
+        map_old_new = {}
+        refund_ids = []
+        for old_inv_id in ids:
+            new_id = super(account_invoice,self).refund(cr, uid, ids, date=date, period_id=period_id, description=description)
+            refund_ids += new_id
+            map_old_new[old_inv_id] = new_id[0]
+        
+        for old_inv_id in map_old_new.keys():
+            old_inv_record = self.read(cr, uid, [old_inv_id], ['price_type'])[0]['price_type']
+            self.write(cr, uid, [map_old_new[old_inv_id]], {'price_type' : old_inv_record})
+        return refund_ids
+    
 account_invoice()
 
 class account_invoice_line(osv.osv):
@@ -46,7 +61,9 @@ class account_invoice_line(osv.osv):
         """
         res = {}
         tax_obj = self.pool.get('account.tax')
+        cur_obj = self.pool.get('res.currency')
         for line in self.browse(cr, uid, ids):
+            cur = line.invoice_id and line.invoice_id.currency_id or False
             res_init = super(account_invoice_line, self)._amount_line(cr, uid, [line.id], name, args, context)
             res[line.id] = {
                 'price_subtotal': 0.0,
@@ -64,13 +81,13 @@ class account_invoice_line(osv.osv):
                         product_taxes = filter(lambda x: x.price_include, line.product_id.supplier_taxes_id)
 
                 if ((set(product_taxes) == set(line.invoice_line_tax_id)) or not product_taxes) and (line.invoice_id.price_type == 'tax_included'):
-                    res[line.id]['price_subtotal_incl'] = res_init[line.id]
+                    res[line.id]['price_subtotal_incl'] = cur and cur_obj.round(cr, uid, cur, res_init[line.id]) or res_init[line.id]
                 else:
-                    res[line.id]['price_subtotal'] = res_init[line.id]
+                    res[line.id]['price_subtotal'] = cur and cur_obj.round(cr, uid, cur, res_init[line.id]) or res_init[line.id]
                     for tax in tax_obj.compute_inv(cr, uid, product_taxes, res_init[line.id]/line.quantity, line.quantity):
-                        res[line.id]['price_subtotal'] = res[line.id]['price_subtotal'] - round(tax['amount'], 2)
+                        res[line.id]['price_subtotal'] = res[line.id]['price_subtotal'] - round(tax['amount'], int(config['price_accuracy']))
             else:
-                res[line.id]['price_subtotal'] = res_init[line.id]
+                res[line.id]['price_subtotal'] = cur and cur_obj.round(cr, uid, cur, res_init[line.id]) or res_init[line.id]
 
             if res[line.id]['price_subtotal']:
                 res[line.id]['price_subtotal_incl'] = res[line.id]['price_subtotal']
@@ -83,8 +100,8 @@ class account_invoice_line(osv.osv):
                     res[line.id]['price_subtotal'] = res[line.id]['price_subtotal'] - tax['amount']
                     res[line.id]['data'].append( tax)
 
-        res[line.id]['price_subtotal']= round(res[line.id]['price_subtotal'], 2)
-        res[line.id]['price_subtotal_incl']= round(res[line.id]['price_subtotal_incl'], 2)
+            res[line.id]['price_subtotal']= round(res[line.id]['price_subtotal'], int(config['price_accuracy']))
+            res[line.id]['price_subtotal_incl']= round(res[line.id]['price_subtotal_incl'], int(config['price_accuracy']))
         return res
 
     def _price_unit_default(self, cr, uid, context=None):
