@@ -104,7 +104,7 @@ class account_voucher(osv.osv):
             ],'Type', readonly=True, select=True , size=128),
         'date':fields.date('Date', readonly=True, states={'draft':[('readonly',False)]}),
         'journal_id':fields.many2one('account.journal', 'Journal', required=True, readonly=True, states={'draft':[('readonly',False)]}),
-        'account_id':fields.many2one('account.account', 'Account', required=True, readonly=True, states={'draft':[('readonly',False)]}),
+        'account_id':fields.many2one('account.account', 'Account', required=True, readonly=True, states={'draft':[('readonly',False)]}, domain=[('type','<>','view')]),
         'payment_ids':fields.one2many('account.voucher.line','voucher_id','Voucher Lines', readonly=False, states={'proforma':[('readonly',True)]}),
         'period_id': fields.many2one('account.period', 'Period', required=True, states={'posted':[('readonly',True)]}),
         'narration':fields.text('Narration', readonly=True, states={'draft':[('readonly',False)]}, required=True),
@@ -170,8 +170,11 @@ class account_voucher(osv.osv):
         total=0
         for i in obj[0].payment_ids:
             total+=i.amount
-        self.write(cr,uid,ids,{'amount':total})
-        self.write(cr, uid, ids, {'state':'proforma'})
+        if total!=0:
+            self.write(cr,uid,ids,{'amount':total})
+            self.write(cr, uid, ids, {'state':'proforma'})
+        else:
+            raise osv.except_osv('Invalid action !', 'You can not post to Pro-Forma a voucher with Total amount = 0')
         return True
     
     def proforma_voucher(self, cr, uid, ids, context={}):
@@ -196,7 +199,7 @@ class account_voucher(osv.osv):
             if t['state'] in ('draft', 'cancel'):
                 unlink_ids.append(t['id'])
             else:
-                raise osv.except_osv('Invalid action !', 'Cannot delete invoice(s) which are already opened or paid !')
+                raise osv.except_osv('Invalid action !', 'Cannot delete Voucher(s) which are already opened or paid !')
         osv.osv.unlink(self, cr, uid, unlink_ids)
         return True
          
@@ -214,7 +217,7 @@ class account_voucher(osv.osv):
         
         for il in iml:
             if il['account_analytic_id']:
-                if inv.type in ('pay_voucher', 'rec_voucher','cont_voucher','bank_pay_voucher','bank_rec_voucher','journal_sale_voucher','journal_pur_voucher'):
+                if inv.type in ('pay_voucher', 'rec_voucher','cont_voucher','bank_pay_voucher','bank_rec_voucher','journal_sale_vou','journal_pur_voucher'):
                     ref = inv.reference
                 else:
                     ref = self._convert_ref(cr, uid, inv.number)
@@ -244,7 +247,7 @@ class account_voucher(osv.osv):
             diff_currency_p = inv.currency_id.id <> company_currency
 
             total = 0
-            if inv.type in ('pay_voucher', 'journal_voucher', 'rec_voucher','cont_voucher','bank_pay_voucher','bank_rec_voucher','journal_sale_voucher','journal_pur_voucher'):
+            if inv.type in ('pay_voucher', 'journal_voucher', 'rec_voucher','cont_voucher','bank_pay_voucher','bank_rec_voucher','journal_sale_vou','journal_pur_voucher'):
                 ref = inv.reference
             else:
                 ref = self._convert_ref(cr, uid, inv.number)
@@ -297,9 +300,9 @@ class account_voucher(osv.osv):
                 name = self.pool.get('ir.sequence').get_id(cr, uid, journal.sequence_id.id)
 
             move = {
-                'name': name, 
+                'name' : name, 
                 'journal_id': journal_id, 
-                'voucher_type':inv.type,
+                'type' : inv.type,
                 'narration' : inv.narration
             }
             if inv.period_id:
@@ -404,7 +407,8 @@ class account_voucher(osv.osv):
     def action_number(self, cr, uid, ids, *args):
         cr.execute('SELECT id, type, number, move_id, reference ' \
                 'FROM account_voucher ' \
-                'WHERE id IN ('+','.join(map(str,ids))+')')
+                'WHERE id IN %s',
+                   (tuple(ids),))
         for (id, invtype, number, move_id, reference) in cr.fetchall():
             if not number:
                 number = self.pool.get('ir.sequence').get(cr, uid, invtype)
@@ -485,7 +489,7 @@ class VoucherLine(osv.osv):
     _columns = {
         'voucher_id':fields.many2one('account.voucher', 'Voucher'),
         'name':fields.char('Description', size=256, required=True),
-        'account_id':fields.many2one('account.account','Account', required=True),
+        'account_id':fields.many2one('account.account','Account', required=True, domain=[('type','<>','view')]),
         'partner_id': fields.many2one('res.partner', 'Partner', change_default=True),
         'amount':fields.float('Amount'),
         'type':fields.selection([('dr','Debit'),('cr','Credit')], 'Type'),
@@ -508,12 +512,11 @@ class VoucherLine(osv.osv):
             res.append(self.move_line_get_item(cr, uid, line, context))
         return res
     
-    def onchange_partner(self, cr, uid, ids, partner_id, ttype,type1):
+    def onchange_partner(self, cr, uid, ids, partner_id, ttype ,type1):
         if not partner_id:
             return {'value' : {'account_id' : False, 'type' : False ,'amount':False}}
         obj = self.pool.get('res.partner')
         account_id = False
-        
         if type1 in ('rec_voucher','bank_rec_voucher', 'journal_voucher'):
             account_id = obj.browse(cr, uid, partner_id).property_account_receivable
             balance = obj.browse(cr,uid,partner_id).credit
