@@ -95,12 +95,19 @@ class auction_dates(osv.osv):
         RETURN: True
         """
         # objects vendus mais non factures
-        cr.execute('select count(*) as c from auction_lots where auction_id in ('+','.join(map(str,ids))+') and state=%s and obj_price>0', ('draft',))
+        cr.execute('SELECT COUNT(*) AS c '
+                   'FROM auction_lots '
+                   'WHERE auction_id IN %s '
+                   'AND state=%s AND obj_price>0', (tuple(ids), 'draft'))
         nbr = cr.fetchone()[0]
         ach_uids = {}
-        cr.execute('select id from auction_lots where auction_id in ('+','.join(map(str,ids))+') and state=%s and obj_price>0', ('draft',))
+        cr.execute('SELECT id FROM auction_lots '
+                   'WHERE auction_id IN %s '
+                   'AND state=%s AND obj_price>0', (tuple(ids), 'draft'))
         r=self.pool.get('auction.lots').lots_invoice(cr, uid, [x[0] for x in cr.fetchall()],{},None)
-        cr.execute('select id from auction_lots where auction_id in ('+','.join(map(str,ids))+') and obj_price>0')
+        cr.execute('SELECT id FROM auction_lots '
+                   'WHERE auction_id IN %s '
+                   'AND obj_price>0', (tuple(ids),))
         ids2 = [x[0] for x in cr.fetchall()]
     #   for auction in auction_ids:
         c=self.pool.get('auction.lots').seller_trans_create(cr, uid, ids2,{})
@@ -113,7 +120,9 @@ auction_dates()
 # Deposits
 #----------------------------------------------------------
 def _inv_uniq(cr, ids):
-    cr.execute('select name from auction_deposit where id in ('+','.join(map(lambda x: str(x), ids))+')')
+    cr.execute('SELECT name FROM auction_deposit '
+               'WHERE id IN %s',
+               (tuple(ids),))
     for datas in cr.fetchall():
         cr.execute('select count(*) from auction_deposit where name=%s', (datas[0],))
         if cr.fetchone()[0]>1:
@@ -229,7 +238,9 @@ def _type_get(self, cr, uid,ids):
 # Lots
 #----------------------------------------------------------
 def _inv_constraint(cr, ids):
-    cr.execute('select id, bord_vnd_id, lot_num from auction_lots where id in ('+','.join(map(lambda x: str(x), ids))+')')
+    cr.execute('SELECT id, bord_vnd_id, lot_num FROM auction_lots '
+               'WHERE id IN %s',
+               (tuple(ids),))
     for datas in cr.fetchall():
         cr.execute('select count(*) from auction_lots where bord_vnd_id=%s and lot_num=%s', (datas[1],datas[2]))
         if cr.fetchone()[0]>1:
