@@ -28,7 +28,7 @@ from report import report_sxw
 
 class auction_bids(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(auction_bids, self).__init__(cr, uid, name, context)
+        super(auction_bids, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
         })
