@@ -34,7 +34,7 @@ class buyer_list(report_sxw.rml_parse):
     sum_buyer_price_val=0.0
     sum_lot_val=0.0
     def __init__(self, cr, uid, name, context):
-        super(buyer_list, self).__init__(cr, uid, name, context)
+        super(buyer_list, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
             'lines_lots_from_auction' : self.lines_lots_from_auction,
@@ -51,7 +51,8 @@ class buyer_list(report_sxw.rml_parse):
         for lot_id  in objects:
             auc_lot_ids.append(lot_id.id)
         self.auc_lot_ids=auc_lot_ids
-        self.cr.execute('select auction_id from auction_lots where id in ('+','.join(map(str,auc_lot_ids))+') group by auction_id')
+        self.cr.execute('SELECT auction_id FROM auction_lots WHERE id IN %s GROUP BY auction_id',
+                        (tuple(auc_lot_ids),))
         auc_date_ids = self.cr.fetchall()
         auct_dat=[]
         for ad_id in auc_date_ids:
@@ -71,13 +72,16 @@ class buyer_list(report_sxw.rml_parse):
 
         auc_date_ids = self.pool.get('auction.dates').search(self.cr,self.uid,([('name','like',obj['name'])]))
 
-#       self.cr.execute('select ach_uid,count(1) as no_lot, sum(obj_price) as adj_price, sum(buyer_price)-sum(obj_price) as buyer_cost ,sum(buyer_price) as to_pay from auction_lots where id in ('+','.join(map(str,self.auc_lot_ids))+') and  auction_id=%s  and ach_uid is not null group by ach_uid ', (auc_date_ids[0],))
-        self.cr.execute('select ach_login as ach_uid,count(1) as no_lot, sum(obj_price) as adj_price, sum(buyer_price)-sum(obj_price) as buyer_cost ,sum(buyer_price) as to_pay from auction_lots where  id in ('+','.join(map(str,self.auc_lot_ids))+') and  auction_id=%s and ach_login is not null  group by ach_login order by ach_login', (auc_date_ids[0],))
+        self.cr.execute('SELECT ach_login AS ach_uid, COUNT(1) AS no_lot, '\
+                        'SUM(obj_price) AS adj_price, '\
+                        'SUM(buyer_price)-SUM(obj_price) AS buyer_cost, '\
+                        'SUM(buyer_price) AS to_pay '\
+                        'FROM auction_lots WHERE id IN %s '\
+                        'AND auction_id=%s AND ach_login IS NOT NULL '\
+                        'GROUP BY ach_login ORDER BY ach_login',
+                        (tuple(self.auc_lot_ids), auc_date_ids[0],))
         res = self.cr.dictfetchall()
         for r in res:
-#           if r['ach_uid']:
-#               tnm=self.pool.get('res.partner').read(self.cr,self.uid,[r['ach_uid']],['name'])#
-#               r.__setitem__('ach_uid',tnm[0]['name'])
                 self.sum_adj_price_val = self.sum_adj_price_val + r['adj_price']
                 self.sum_buyer_obj_price_val = self.sum_buyer_obj_price_val + r['buyer_cost']
                 self.sum_buyer_price_val = self.sum_buyer_price_val + r['to_pay']
