@@ -28,7 +28,7 @@ from report import report_sxw
 
 class deposit_seller(report_sxw.rml_parse):
     def __init__(self, cr, uid, name, context):
-        super(deposit_seller, self).__init__(cr, uid, name, context)
+        super(deposit_seller, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
 
