@@ -363,8 +363,8 @@ class actions_server(osv.osv):
     def _select_signals(self, cr, uid, context={}):
         cr.execute("select distinct t.signal as key, t.signal || ' - [ ' || w.osv || ' ] ' as val from wkf w, wkf_activity a, wkf_transition t "\
                         " where w.id = a.wkf_id " \
-                        " and t.act_from = a.wkf_id " \
-                        " or t.act_to = a.wkf_id and t.signal not in (null, NULL)")
+                        " and t.act_from = a.id " \
+                        " or t.act_to = a.id and t.signal not in (null, NULL)")
         result = cr.fetchall() or []
         res = []
         for rs in result:
@@ -419,8 +419,7 @@ class actions_server(osv.osv):
         'type': lambda *a: 'ir.actions.server',
         'sequence': lambda *a: 5,
         'code': lambda *a: """# You can use the following variables
-#    - object
-#    - object2
+#    - object or obj
 #    - time
 #    - cr
 #    - uid
@@ -481,7 +480,7 @@ class actions_server(osv.osv):
             result = eval(exp, {'object':obj, 'context': context,'time':time})
             if result in (None, False):
                 return str("--------")
-            return str(result)
+            return tools.ustr(result)
         
         com = re.compile('(\[\[.+?\]\])')
         message = com.sub(merge, keystr)
@@ -520,18 +519,25 @@ class actions_server(osv.osv):
                 return result
 
             if action.state=='code':
-                localdict = {
-                    'self': self.pool.get(action.model_id.model),
-                    'context': context,
-                    'time': time,
-                    'ids': ids,
-                    'cr': cr,
-                    'uid': uid,
-                    'obj':obj
-                }
-                exec action.code in localdict
-                if 'action' in localdict:
-                    return localdict['action']
+                if config['server_actions_allow_code']:
+                    localdict = {
+                        'self': self.pool.get(action.model_id.model),
+                        'context': context,
+                        'time': time,
+                        'ids': ids,
+                        'cr': cr,
+                        'uid': uid,
+                        'object':obj
+                        }
+                    exec action.code in localdict
+                    if 'action' in localdict:
+                        return localdict['action']
+                else:
+                    netsvc.Logger().notifyChannel(
+                        self._name, netsvc.LOG_ERROR,
+                        "%s is a `code` server action, but "
+                        "it isn't allowed in this configuration.\n\n"
+                        "See server options to enable it"%action)
 
             if action.state == 'email':
                 user = config['email_from']
@@ -544,10 +550,10 @@ class actions_server(osv.osv):
                 if not address:
                     raise osv.except_osv(_('Error'), _("Please specify the Partner Email address !"))
                 if not user:
-                    raise osv.except_osv(_('Error'), _("Please specify server option --smtp-from !"))
+                    raise osv.except_osv(_('Error'), _("Please specify server option --email-from !"))
                 
-                subject = self.merge_message(cr, uid, str(action.subject), action, context)
-                body = self.merge_message(cr, uid, str(action.message), action, context)
+                subject = self.merge_message(cr, uid, action.subject, action, context)
+                body = self.merge_message(cr, uid, action.message, action, context)
                 
                 if tools.email_send(user, [address], subject, body, debug=False, subtype='html') == True:
                     logger.notifyChannel('email', netsvc.LOG_INFO, 'Email successfully send to : %s' % (address))
@@ -565,14 +571,8 @@ class actions_server(osv.osv):
             if action.state == 'sms':
                 #TODO: set the user and password from the system
                 # for the sms gateway user / password
-                api_id = ''
-                text = action.sms
-                to = self.get_mobile(cr, uid, action, context)
-                #TODO: Apply message mearge with the field
-                if tools.sms_send(user, password, api_id, text, to) == True:
-                    logger.notifyChannel('sms', netsvc.LOG_INFO, 'SMS successfully send to : %s' % (action.address))
-                else:
-                    logger.notifyChannel('sms', netsvc.LOG_ERROR, 'Failed to send SMS to : %s' % (action.address))
+                # USE smsclient module from extra-addons
+                logger.notifyChannel('sms', netsvc.LOG_ERROR, 'SMS Facility has not been implemented yet. Use smsclient module!')
             
             if action.state == 'other':
                 res = []
