@@ -31,7 +31,9 @@ class ir_attachment(osv.osv):
         ima = self.pool.get('ir.model.access')
         if isinstance(ids, (int, long)):
             ids = [ids]
-        cr.execute('select distinct res_model from ir_attachment where id in ('+','.join(map(str, ids))+')')
+        cr.execute('select distinct res_model from ir_attachment where id in %s',
+                   (tuple(ids),)
+                  )
         for obj in cr.fetchall():
             if obj[0]:
                 ima.check(cr, uid, obj[0], mode, context=context)
@@ -91,8 +93,9 @@ class ir_attachment(osv.osv):
         result = {}
         if context is None:
             context = {}
-        context['bin_size'] = False
-        for i in self.browse(cr, uid, ids, context=context):
+        ctx = context.copy()    
+        ctx['bin_size'] = False
+        for i in self.browse(cr, uid, ids, context=ctx):
             result[i.id] = False
             for format in ('png','jpg','jpeg','gif','bmp'):
                 if (i.datas_fname and i.datas_fname.lower() or '').endswith(format):
