@@ -75,15 +75,19 @@ class ir_model(osv.osv):
         if context:
             context.pop('__last_update', None)
         return super(ir_model,self).write(cr, user, ids, vals, context)
-
+        
     def create(self, cr, user, vals, context=None):
+        if not context:
+            context = {}
         if context and context.get('manual',False):
             vals['state']='manual'
         res = super(ir_model,self).create(cr, user, vals, context)
         if vals.get('state','base')=='manual':
             self.instanciate(cr, user, vals['model'], context)
             self.pool.get(vals['model']).__init__(self.pool, cr)
-            self.pool.get(vals['model'])._auto_init(cr,{})
+            ctx = context.copy()
+            ctx.update({'field_name':vals['name'],'field_state':'manual','select':vals.get('select_level','0')})
+            self.pool.get(vals['model'])._auto_init(cr, ctx)
             #pooler.restart_pool(cr.dbname)
         return res
 
@@ -113,10 +117,10 @@ class ir_model_grid(osv.osv):
         result = super(osv.osv, self).read(cr, uid, ids, fields, context, load)
         allgr = self.pool.get('res.groups').search(cr, uid, [], context=context)
         acc_obj = self.pool.get('ir.model.access')
-        
+
         if not isinstance(result,list):
             result=[result]
-            
+
         for res in result:
             rules = acc_obj.search(cr, uid, [('model_id', '=', res['id'])])
             rules_br = acc_obj.browse(cr, uid, rules, context=context)
@@ -235,31 +239,39 @@ class ir_model_fields(osv.osv):
     def unlink(self, cr, user, ids, context=None):
         for field in self.browse(cr, user, ids, context):
             if field.state <> 'manual':
-                raise except_orm(_('Error'), _("You can not remove the field '%s' !") %(field.name,))
+                raise except_orm(_('Error'), _("You cannot remove the field '%s' !") %(field.name,))
         #
         # MAY BE ADD A ALTER TABLE DROP ?
         #
+            #Removing _columns entry for that table
+            self.pool.get(field.model)._columns.pop(field.name,None)
         return super(ir_model_fields, self).unlink(cr, user, ids, context)
 
     def create(self, cr, user, vals, context=None):
         if 'model_id' in vals:
             model_data = self.pool.get('ir.model').browse(cr, user, vals['model_id'])
             vals['model'] = model_data.model
+        if context is None:
+            context = {}
         if context and context.get('manual',False):
             vals['state'] = 'manual'
-        res = super(ir_model_fields,self).create(cr, user, vals, context)    
+        res = super(ir_model_fields,self).create(cr, user, vals, context)
         if vals.get('state','base') == 'manual':
             if not vals['name'].startswith('x_'):
                 raise except_orm(_('Error'), _("Custom fields must have a name that starts with 'x_' !"))
-            
-            if 'relation' in vals and not self.pool.get('ir.model').search(cr, user, [('model','=',vals['relation'])]):
+
+            if vals.get('relation',False) and not self.pool.get('ir.model').search(cr, user, [('model','=',vals['relation'])]):
                  raise except_orm(_('Error'), _("Model %s Does not Exist !" % vals['relation']))
-                 
+
             if self.pool.get(vals['model']):
                 self.pool.get(vals['model']).__init__(self.pool, cr)
-                self.pool.get(vals['model'])._auto_init(cr, {})
-                
+                #Added context to _auto_init for special treatment to custom field for select_level
+                ctx = context.copy()
+                ctx.update({'field_name':vals['name'],'field_state':'manual','select':vals.get('select_level','0'),'update_custom_fields':True})
+                self.pool.get(vals['model'])._auto_init(cr, ctx)
+
         return res
+    
 ir_model_fields()
 
 class ir_model_access(osv.osv):
@@ -267,7 +279,7 @@ class ir_model_access(osv.osv):
     _columns = {
         'name': fields.char('Name', size=64, required=True),
         'model_id': fields.many2one('ir.model', 'Object', required=True),
-        'group_id': fields.many2one('res.groups', 'Group'),
+        'group_id': fields.many2one('res.groups', 'Group', ondelete='cascade'),
         'perm_read': fields.boolean('Read Access'),
         'perm_write': fields.boolean('Write Access'),
         'perm_create': fields.boolean('Create Access'),
@@ -415,10 +427,11 @@ class ir_model_data(osv.osv):
     _defaults = {
         'date_init': lambda *a: time.strftime('%Y-%m-%d %H:%M:%S'),
         'date_update': lambda *a: time.strftime('%Y-%m-%d %H:%M:%S'),
-        'noupdate': lambda *a: False
+        'noupdate': lambda *a: False,
+        'module': lambda *a: ''
     }
     _sql_constraints = [
-        ('module_name_uniq', 'unique(name, module)', 'You can not have multiple records with the same id for the same module'),
+        ('module_name_uniq', 'unique(name, module)', 'You cannot have multiple records with the same id for the same module'),
     ]
 
     def __init__(self, pool, cr):
@@ -431,7 +444,7 @@ class ir_model_data(osv.osv):
     def _get_id(self, cr, uid, module, xml_id):
         ids = self.search(cr, uid, [('module','=',module),('name','=', xml_id)])
         if not ids:
-            raise Exception('No references to %s.%s' % (module, xml_id))
+            raise ValueError('No references to %s.%s' % (module, xml_id))
         # the sql constraints ensure us we have only one result
         return ids[0]
 
@@ -445,10 +458,11 @@ class ir_model_data(osv.osv):
             id = False
         return id
 
-    def _update(self,cr, uid, model, module, values, xml_id=False, store=True, noupdate=False, mode='init', res_id=False):
+    def _update(self,cr, uid, model, module, values, xml_id=False, store=True, noupdate=False, mode='init', res_id=False, context=None):
         warning = True
         model_obj = self.pool.get(model)
-        context = {}
+        if not context:
+            context = {}
         if xml_id and ('.' in xml_id):
             assert len(xml_id.split('.'))==2, _('"%s" contains too many dots. XML ids should not contain dots ! These are used to refer to other modules data, as in module.reference_id') % (xml_id)
             warning = False
@@ -456,7 +470,7 @@ class ir_model_data(osv.osv):
         if (not xml_id) and (not self.doinit):
             return False
         action_id = False
-        
+
         if xml_id:
             cr.execute('select id,res_id from ir_model_data where module=%s and name=%s', (module,xml_id))
             results = cr.fetchall()
@@ -471,12 +485,12 @@ class ir_model_data(osv.osv):
                     res_id,action_id = res_id2,action_id2
 
         if action_id and res_id:
-            model_obj.write(cr, uid, [res_id], values)
+            model_obj.write(cr, uid, [res_id], values, context=context)
             self.write(cr, uid, [action_id], {
                 'date_update': time.strftime('%Y-%m-%d %H:%M:%S'),
-                })
+                },context=context)
         elif res_id:
-            model_obj.write(cr, uid, [res_id], values)
+            model_obj.write(cr, uid, [res_id], values, context=context)
             if xml_id:
                 self.create(cr, uid, {
                     'name': xml_id,
@@ -484,21 +498,21 @@ class ir_model_data(osv.osv):
                     'module':module,
                     'res_id':res_id,
                     'noupdate': noupdate,
-                    })
+                    },context=context)
                 if model_obj._inherits:
                     for table in model_obj._inherits:
                         inherit_id = model_obj.browse(cr, uid,
-                                res_id)[model_obj._inherits[table]]
+                                res_id,context=context)[model_obj._inherits[table]]
                         self.create(cr, uid, {
                             'name': xml_id + '_' + table.replace('.', '_'),
                             'model': table,
                             'module': module,
                             'res_id': inherit_id,
                             'noupdate': noupdate,
-                            })
+                            },context=context)
         else:
             if mode=='init' or (mode=='update' and xml_id):
-                res_id = model_obj.create(cr, uid, values)
+                res_id = model_obj.create(cr, uid, values, context=context)
                 if xml_id:
                     self.create(cr, uid, {
                         'name': xml_id,
@@ -506,18 +520,18 @@ class ir_model_data(osv.osv):
                         'module': module,
                         'res_id': res_id,
                         'noupdate': noupdate
-                        })
+                        },context=context)
                     if model_obj._inherits:
                         for table in model_obj._inherits:
                             inherit_id = model_obj.browse(cr, uid,
-                                    res_id)[model_obj._inherits[table]]
+                                    res_id,context=context)[model_obj._inherits[table]]
                             self.create(cr, uid, {
                                 'name': xml_id + '_' + table.replace('.', '_'),
                                 'model': table,
                                 'module': module,
                                 'res_id': inherit_id,
                                 'noupdate': noupdate,
-                                })
+                                },context=context)
         if xml_id:
             if res_id:
                 self.loads[(module, xml_id)] = (model, res_id)
@@ -544,30 +558,32 @@ class ir_model_data(osv.osv):
             res_id=None
             model = models[0]
 
+        clause = "model=%s AND key=%s AND name=%s"
+        params = (model, key, name)
         if res_id:
-            where = ' and res_id=%s' % (res_id,)
+            clause += ' AND res_id=%s'
+            params += (res_id,)
         else:
-            where = ' and (res_id is null)'
+            clause += ' AND (res_id IS NULL)'
 
         if key2:
-            where += ' and key2=\'%s\'' % (key2,)
+            clause += ' AND key2=%s'
+            params += (key2,)
         else:
-            where += ' and (key2 is null)'
+            clause += ' AND (key2 IS NULL)'
 
-        cr.execute('select * from ir_values where model=%s and key=%s and name=%s'+where,(model, key, name))
+        cr.execute('SELECT 1 FROM ir_values WHERE ' + clause, params)
         res = cr.fetchone()
         if not res:
-            res = ir.ir_set(cr, uid, key, key2, name, models, value, replace, isobject, meta)
+            ir.ir_set(cr, uid, key, key2, name, models, value, replace, isobject, meta)
         elif xml_id:
-            cr.execute('UPDATE ir_values set value=%s WHERE model=%s and key=%s and name=%s'+where,(value, model, key, name))
+            cr.execute('UPDATE ir_values SET value=%s WHERE ' + clause, (value,) + params)
         return True
 
     def _process_end(self, cr, uid, modules):
         if not modules:
             return True
-        modules = list(modules)    
-        module_in = ",".join(["%s"] * len(modules))
-        cr.execute('select id,name,model,res_id,module from ir_model_data where module in (' + module_in + ') and noupdate=%s', modules + [False])
+        cr.execute('select id,name,model,res_id,module from ir_model_data where module in %s and noupdate=%s', (tuple(modules), False))
         wkf_todo = []
         for (id, name, model, res_id,module) in cr.fetchall():
             if (module,name) not in self.loads:
