@@ -43,24 +43,6 @@ class ir_rule_group(osv.osv):
         'global': lambda *a: True,
     }
 
-    def unlink(self, cr, uid, ids, context=None):
-        res = super(ir_rule_group, self).unlink(cr, uid, ids, context=context)
-        # Restart the cache on the domain_get method of ir.rule
-        self.pool.get('ir.rule').domain_get.clear_cache(cr.dbname)
-        return res
-
-    def create(self, cr, user, vals, context=None):
-        res = super(ir_rule_group, self).create(cr, user, vals, context=context)
-        # Restart the cache on the domain_get method of ir.rule
-        self.pool.get('ir.rule').domain_get.clear_cache(cr.dbname)
-        return res
-
-    def write(self, cr, uid, ids, vals, context=None):
-        res = super(ir_rule_group, self).write(cr, uid, ids, vals, context=context)
-        # Restart the cache on the domain_get method of ir.rule
-        self.pool.get('ir.rule').domain_get.clear_cache(cr.dbname)
-        return res
-
 ir_rule_group()
 
 
@@ -107,9 +89,14 @@ class ir_rule(osv.osv):
         for rule in self.browse(cr, uid, ids, context):
             eval_user_data = {'user': self.pool.get('res.users').browse(cr, 1, uid),
                             'time':time}
+            
             if rule.domain_force:
                 res[rule.id] = eval(rule.domain_force, eval_user_data)
             else:
+                if rule.operand and rule.operand.startswith('user.') and rule.operand.count('.') > 1:
+                    #Need to check user.field.field1.field2(if field  is False,it will break the chain)
+                    op = rule.operand[5:]
+                    rule.operand = rule.operand[:5+len(op[:op.find('.')])] +' and '+ rule.operand + ' or False'
                 if rule.operator in ('in', 'child_of'):
                     dom = eval("[('%s', '%s', [%s])]" % (rule.field_id.name, rule.operator,
                         eval(rule.operand,eval_user_data)), eval_user_data)
@@ -205,27 +192,6 @@ class ir_rule(osv.osv):
         if query:
             query = '('+query+')'
         return query, val
-    domain_get = tools.cache()(domain_get)
-
-    def unlink(self, cr, uid, ids, context=None):
-        res = super(ir_rule, self).unlink(cr, uid, ids, context=context)
-        # Restart the cache on the domain_get method of ir.rule
-        self.domain_get.clear_cache(cr.dbname)
-        return res
-
-    def create(self, cr, user, vals, context=None):
-        res = super(ir_rule, self).create(cr, user, vals, context=context)
-        # Restart the cache on the domain_get method of ir.rule
-        self.domain_get.clear_cache(cr.dbname)
-        return res
-
-    def write(self, cr, uid, ids, vals, context=None):
-        if not context:
-            context={}
-        res = super(ir_rule, self).write(cr, uid, ids, vals, context=context)
-        # Restart the cache on the domain_get method
-        self.domain_get.clear_cache(cr.dbname)
-        return res
 
 ir_rule()
 
