@@ -36,6 +36,7 @@ TRANSLATION_TYPE = [
     ('help', 'Help'),
     ('code', 'Code'),
     ('constraint', 'Constraint'),
+    ('sql_constraint', 'SQL Constraint')    
 ]
 
 class ir_translation(osv.osv):
@@ -88,8 +89,8 @@ class ir_translation(osv.osv):
                     'where lang=%s ' \
                         'and type=%s ' \
                         'and name=%s ' \
-                        'and res_id in ('+','.join(map(str, ids))+')',
-                    (lang,tt,name))
+                        'and res_id in %s',
+                    (lang, tt ,name, tuple(ids)))
             for res_id, value in cr.fetchall():
                 translations[res_id] = value
         return translations
@@ -107,9 +108,8 @@ class ir_translation(osv.osv):
                 'where lang=%s ' \
                     'and type=%s ' \
                     'and name=%s ' \
-                    'and res_id in ('+','.join(map(str,ids))+')',
-                (lang,tt,name))
-        cr.commit()
+                    'and res_id in %s',
+                (lang, tt, name, tuple(ids)))
         for id in ids:
             self.create(cr, uid, {
                 'lang':lang,
@@ -132,44 +132,44 @@ class ir_translation(osv.osv):
                         'and type=%s ' \
                         'and name=%s ' \
                         'and src=%s',
-                    (lang, tt, str(name), source))
+                    (lang, tt, tools.ustr(name), source))
         else:
             cr.execute('select value ' \
                     'from ir_translation ' \
                     'where lang=%s ' \
                         'and type=%s ' \
                         'and name=%s',
-                    (lang, tt, str(name)))
+                    (lang, tt, tools.ustr(name)))
         res = cr.fetchone()
         trad = res and res[0] or ''
         return trad
-        
+
     def create(self, cursor, user, vals, context=None):
         if not context:
             context = {}
         ids = super(ir_translation, self).create(cursor, user, vals, context=context)
-        for trans_obj in self.read(cursor, user, [ids], ['name','type','res_id'], context=context):
-            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], lang=context.get('lang','en_US'))
-            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], context.get('lang','en_US'), [trans_obj['res_id']])
-        return ids    
+        for trans_obj in self.read(cursor, user, [ids], ['name','type','res_id','src','lang'], context=context):
+            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], source=trans_obj['src'])
+            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], [trans_obj['res_id']])
+        return ids
 
     def write(self, cursor, user, ids, vals, context=None):
         if not context:
             context = {}
         result = super(ir_translation, self).write(cursor, user, ids, vals, context=context)
-        for trans_obj in self.read(cursor, user, ids, ['name','type','res_id'], context=context):
-            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], lang=context.get('lang','en_US'))
-            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], context.get('lang','en_US'), [trans_obj['res_id']])
+        for trans_obj in self.read(cursor, user, ids, ['name','type','res_id','src','lang'], context=context):
+            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], source=trans_obj['src'])
+            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], [trans_obj['res_id']])
         return result
 
     def unlink(self, cursor, user, ids, context=None):
         if not context:
             context = {}
-        for trans_obj in self.read(cursor, user, ids, ['name','type','res_id'], context=context):
-            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], lang=context.get('lang','en_US'))
-            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], context.get('lang','en_US'), [trans_obj['res_id']])
+        for trans_obj in self.read(cursor, user, ids, ['name','type','res_id','src','lang'], context=context):
+            self._get_source.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], source=trans_obj['src'])
+            self._get_ids.clear_cache(cursor.dbname, user, trans_obj['name'], trans_obj['type'], trans_obj['lang'], [trans_obj['res_id']])
         result = super(ir_translation, self).unlink(cursor, user, ids, context=context)
-        return result    
+        return result
 
 ir_translation()
 
