@@ -66,7 +66,7 @@ class view(osv.osv):
         'field_parent': fields.char('Child Field',size=64),
     }
     _defaults = {
-        'arch': lambda *a: '<?xml version="1.0"?>\n<tree string="Unknwown">\n\t<field name="name"/>\n</tree>',
+        'arch': lambda *a: '<?xml version="1.0"?>\n<tree string="My View">\n\t<field name="name"/>\n</tree>',
         'priority': lambda *a: 16
     }
     _order = "priority"
@@ -150,6 +150,10 @@ class view_sc(osv.osv):
         'resource': lambda *a: 'ir.ui.menu',
         'user_id': lambda obj, cr, uid, context: uid,
     }
+    _sql_constraints = [
+        ('shortcut_unique', 'unique(res_id, user_id)', 'Shortcut for this menu already exists!'),
+    ]
+        
 view_sc()
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
