@@ -66,7 +66,16 @@ class module_category(osv.osv):
     _description = "Module Category"
 
     def _module_nbr(self,cr,uid, ids, prop, unknow_none,context):
-        cr.execute('select category_id,count(*) from ir_module_module where category_id in ('+','.join(map(str,ids))+') or category_id in (select id from ir_module_category where parent_id in ('+','.join(map(str,ids))+')) group by category_id')
+        cr.execute('SELECT category_id, COUNT(*) \
+                      FROM ir_module_module \
+                     WHERE category_id IN %(ids)s \
+                        OR category_id IN (SELECT id \
+                                             FROM ir_module_category \
+                                            WHERE parent_id IN %(ids)s) \
+                     GROUP BY category_id', {'ids': tuple(ids)}
+
+                    )
+
         result = dict(cr.fetchall())
         for id in ids:
             cr.execute('select id from ir_module_category where parent_id=%s', (id,))
@@ -168,11 +177,13 @@ class module(osv.osv):
         ], string='State', readonly=True),
         'demo': fields.boolean('Demo data'),
         'license': fields.selection([
-                ('GPL-2', 'GPL-2'),
+                ('GPL-2', 'GPL Version 2'),
                 ('GPL-2 or any later version', 'GPL-2 or later version'),
-                ('GPL-3', 'GPL-3'),
+                ('GPL-3', 'GPL Version 3'),
                 ('GPL-3 or any later version', 'GPL-3 or later version'),
-                ('Other proprietary', 'Other proprietary')
+                ('AGPL-3', 'Affero GPL-3'),
+                ('Other OSI approved licence', 'Other OSI Approved Licence'),
+                ('Other proprietary', 'Other Proprietary')
             ], string='License', readonly=True),
         'menus_by_module': fields.function(_get_views, method=True, string='Menus', type='text', multi="meta", store=True),
         'reports_by_module': fields.function(_get_views, method=True, string='Reports', type='text', multi="meta", store=True),
@@ -183,7 +194,7 @@ class module(osv.osv):
     _defaults = {
         'state': lambda *a: 'uninstalled',
         'demo': lambda *a: False,
-        'license': lambda *a: 'GPL-2',
+        'license': lambda *a: 'AGPL-3',
     }
     _order = 'name'
 
@@ -197,10 +208,18 @@ class module(osv.osv):
             return True
         if isinstance(ids, (int, long)):
             ids = [ids]
-        for mod in self.read(cr, uid, ids, ['state'], context):
+        mod_names = []    
+        for mod in self.read(cr, uid, ids, ['state','name'], context):
             if mod['state'] in ('installed', 'to upgrade', 'to remove', 'to install'):
                 raise orm.except_orm(_('Error'),
                         _('You try to remove a module that is installed or will be installed'))
+            mod_names.append(mod['name'])
+        #Removing the entry from ir_model_data
+        ids_meta = self.pool.get('ir.model.data').search(cr, uid, [('name', '=', 'module_meta_information'), ('module', 'in', mod_names)])
+        
+        if ids_meta:
+            self.pool.get('ir.model.data').unlink(cr, uid, ids_meta, context)
+
         return super(module, self).unlink(cr, uid, ids, context=context)
 
     def state_update(self, cr, uid, ids, newstate, states_to_update, context={}, level=100):
