@@ -26,7 +26,6 @@ import ir
 
 from tools.misc import currency
 from tools.translate import _
-from tools import config
 
 import mx.DateTime
 from mx.DateTime import RelativeDateTime, now, DateTime, localtime
@@ -40,7 +39,7 @@ class res_currency(osv.osv):
             date=time.strftime('%Y-%m-%d')
         date= date or time.strftime('%Y-%m-%d')
         for id in ids:
-            cr.execute("SELECT currency_id, rate FROM res_currency_rate WHERE currency_id = %s AND name <= '%s' ORDER BY name desc LIMIT 1" % (id, date))
+            cr.execute("SELECT currency_id, rate FROM res_currency_rate WHERE currency_id = %s AND name <= %s ORDER BY name desc LIMIT 1", (id, date))
             if cr.rowcount:
                 id, rate=cr.fetchall()[0]
                 res[id]=rate
@@ -68,7 +67,9 @@ class res_currency(osv.osv):
         if currency.rounding == 0:
             return 0.0
         else:
-            return round(amount / currency.rounding, int(config['price_accuracy'])) * currency.rounding
+            # /!\ First member below must be rounded to full unit!
+            # Do not pass a rounding digits value to round()
+            return round(amount / currency.rounding) * currency.rounding
 
     def is_zero(self, cr, uid, currency, amount):
         return abs(self.round(cr, uid, currency, amount)) < currency.rounding
@@ -76,7 +77,9 @@ class res_currency(osv.osv):
     def compute(self, cr, uid, from_currency_id, to_currency_id, from_amount, round=True, context={}, account=None, account_invert=False):
         if not from_currency_id:
             from_currency_id = to_currency_id
-        xc=self.browse(cr, uid, [from_currency_id,to_currency_id], context=context)
+        if not to_currency_id:
+            to_currency_id = from_currency_id
+        xc = self.browse(cr, uid, [from_currency_id,to_currency_id], context=context)
         from_currency = (xc[0].id == from_currency_id and xc[0]) or xc[1]
         to_currency = (xc[0].id == to_currency_id and xc[0]) or xc[1]
         if from_currency['rate'] == 0 or to_currency['rate'] == 0:
