@@ -25,6 +25,7 @@ import time
 import tools
 from osv import fields,osv,orm
 from tools.translate import _
+from tools import ustr
 
 #class ir_model_fields(osv.osv):
 #   _inherit = 'ir.model.fields'
@@ -55,6 +56,21 @@ class report_creator(osv.osv):
     #
     # Should request only used fields
     #
+    def export_data(self, cr, uid, ids, fields_to_export, context=None):
+        data_l = self.read(cr, uid, ids, ['sql_query'], context)
+        final_datas =[]
+        for i in data_l:
+            datas = []
+            for key,value in i.items():
+                if key not in fields_to_export:
+                    continue
+                if isinstance(value,tuple):
+                    datas.append(ustr(value[1]))
+                else:
+                    datas.append(ustr(value))
+            final_datas += [datas]
+        return {'datas':final_datas}
+        
     def fields_get(self, cr, user, fields=None, context=None):
         if (not context) or 'report_id' not in context:
             return super(report_creator, self).fields_get(cr, user, fields, context)
@@ -65,8 +81,12 @@ class report_creator(osv.osv):
         fields = {}
         i = 0
         for f in report.field_ids:
-            fields['field'+str(i)] = models[f.field_id.model][f.field_id.name]
-            i+=1
+            if f.field_id.model:
+                fields['field'+str(i)] = models[f.field_id.model][f.field_id.name]
+                i+=1
+            else:
+                fields['column_count'] = {'readonly': True, 'type': 'integer', 'string': 'Count', 'size': 64, 'name': 'column_count'}
+            
         return fields
 
     #
@@ -82,17 +102,27 @@ class report_creator(osv.osv):
         fields = {}
         i = 0
         for f in report.field_ids:
-            fields['field'+str(i)] = models[f.field_id.model][f.field_id.name]
-            i+=1
+            if f.field_id.model:
+                fields['field'+str(i)] = models[f.field_id.model][f.field_id.name]
+                i+=1
+            else:
+                fields['column_count'] = {'readonly': True, 'type': 'integer', 'string': 'Count', 'size': 64, 'name': 'column_count'}
+            
         arch = '<?xml version="1.0" encoding="utf-8"?>\n'
         if view_type=='graph':
-            arch +='<graph string="%s" type="%s" orientation="%s">' % (report.name, report.view_graph_type,report.view_graph_orientation)
+            orientation_eval = {'horz':'horizontal','vert' :'vertical'}
+            orientation = eval(report.view_graph_orientation,orientation_eval)
+            arch +='<graph string="%s" type="%s" orientation="%s">' % (report.name, report.view_graph_type, orientation)
+            i = 0
             for val in ('x','y'):
-                i = 0
                 for f in report.field_ids:
                     if f.graph_mode==val:
-                        arch += '<field name="%s" select="1"/>' % ('field'+str(i),)
-                    i+=1
+                        if f.field_id.model:
+                            arch += '<field name="%s" select="1"/>' % ('field'+str(i),)
+                            i+=1
+                        else:
+                            arch += '<field name="%s" select="1"/>' % ('column_count',)
+                    
         elif view_type=='calendar':
             required_types = ['date_start','date_delay','color']
             set_dict = {'view_type':view_type,'string':report.name}
@@ -100,21 +130,41 @@ class report_creator(osv.osv):
             i=0
             for f in report.field_ids:
                 if f.calendar_mode and f.calendar_mode in required_types:
-                    set_dict[f.calendar_mode] = 'field'+str(i)
-                    i+=1
+                    if f.field_id.model:
+                        field_cal = 'field'+str(i)
+                        i+=1
+                    else:
+                        field_cal = 'column_count'
+                    set_dict[f.calendar_mode] = field_cal   
                     del required_types[required_types.index(f.calendar_mode)]
                     
                 else:
-                    temp_list.append('''<field name="%(name)s" select="1"/>''' % {'name':'field'+str(i)})
-                    i+=1
-            arch += '''<%(view_type)s string="%(string)s" date_start="%(date_start)s" date_delay="%(date_delay)s" color="%(color)s">''' %set_dict
+                    if f.field_id.model:
+                        temp_list.append('''<field name="%(name)s" select="1"/>''' % {'name':'field'+str(i)})
+                        i+=1
+                    else:
+                        temp_list.append('''<field name="%(name)s" select="1"/>''' % {'name':'column_count'})    
+                    
+            arch += '''<%(view_type)s string="%(string)s" date_start="%(date_start)s" ''' %set_dict
+            if set_dict.get('date_delay',False):
+                arch +=''' date_delay="%(date_delay)s"  '''%set_dict
+            
+            if set_dict.get('date_stop',False):
+                arch +=''' date_stop="%(date_stop)s" '''%set_dict      
+            
+            if set_dict.get('color',False):
+                arch +=''' color="%(color)s"'''%set_dict
+            arch += '''>'''
             arch += ''.join(temp_list)
         else:
             arch += '<%s string="%s">\n' % (view_type, report.name)
             i = 0
             for f in report.field_ids:
-                arch += '<field name="%s" select="1"/>' % ('field'+str(i),)
-                i+=1
+                if f.field_id.model:
+                    arch += '<field name="%s" select="1"/>' % ('field'+str(i),)
+                    i+=1
+                else:
+                    arch += '<field name="%s" select="1"/>' % ('column_count',)
         arch += '</%s>' % (view_type,)
         result = {
             'arch': arch,
@@ -158,14 +208,20 @@ class report_creator(osv.osv):
         i = 0
         fields = {}
         for f in report.field_ids:
-            fields['field'+str(i)] = (f.field_id.model, f.field_id.name)
-            i+=1
+            if f.field_id.model:
+                fields['field'+str(i)] = (f.field_id.model, f.field_id.name)
+                i+=1
+            else:
+                fields['column_count'] = (False, 'Count')   
         newargs = []
         newargs2 = []
         for a in args:
-            res =  self.pool.get(fields[a[0]][0])._where_calc(cr, user, [[fields[a[0]][1],a[1],a[2]]], active_test=False, context=context)
-            newargs+=res[0]
-            newargs2+=res[1]
+            if fields[a[0]][0]:
+                res = self.pool.get(fields[a[0]][0])._where_calc(cr, user, [[fields[a[0]][1],a[1],a[2]]], active_test=False, context=context)
+                newargs+=res[0]
+                newargs2+=res[1]
+            else:
+                newargs += [("count(*) " + a[1] +" " + str(a[2]))]
         ctx = context or {}
         ctx['getid'] = True
         report = self._sql_query_get(cr, user, [context['report_id']], 'sql_query', None, ctx, where_plus=newargs, limit=limit, offset=offset)
@@ -188,9 +244,18 @@ class report_creator(osv.osv):
         from_list = []
         where_list = []
         filter_list = []
+        
+#        def _add_inherits(obj):
+#            pool_model = self.pool.get(obj)
+#            if not model_dict.get(obj,False):
+#                model_dict[obj] = pool_model._table
+#            for record in pool_model._inherits.keys():
+#                     _add_inherits(record)    
+        
         for model in models:            
             model_dict[model.model] = self.pool.get(model.model)._table
-        
+#            _add_inherits(model.model)
+            
         model_list = model_dict.keys()
         reference_model_dict = {}
         for model in model_dict:
@@ -199,10 +264,22 @@ class report_creator(osv.osv):
             rest_list.remove(model)
             model_pool = self.pool.get(model)
             fields_get = model_pool.fields_get(cr,uid)
+            model_columns = {}
+            
+            def _get_inherit_fields(obj):
+                pool_model = self.pool.get(obj)
+                #Adding the columns of the model itself
+                model_columns.update(pool_model._columns)
+                #Adding the columns of its _inherits
+                for record in pool_model._inherits.keys():
+                     _get_inherit_fields(record)
+
+            _get_inherit_fields(model)         
+            
             fields_filter = dict(filter(lambda x:x[1].get('relation',False) 
                                         and x[1].get('relation') in rest_list 
                                         and x[1].get('type')=='many2one' 
-                                        and not (isinstance(model_pool._columns[x[0]],fields.function) or isinstance(model_pool._columns[x[0]],fields.related)), fields_get.items()))
+                                        and not (isinstance(model_columns[x[0]],fields.function) or isinstance(model_columns[x[0]],fields.related)), fields_get.items()))
             if fields_filter:
                 model in model_list and model_list.remove(model)
             model_count = reference_model_dict.get(model,False)
@@ -217,9 +294,9 @@ class report_creator(osv.osv):
                     reference_model_dict[v.get('relation')] = relation_count+1
                 else:
                     reference_model_dict[v.get('relation')]=1
-                   
-                str_where = model_dict.get(model)+"."+ k + "=" + model_dict.get(v.get('relation'))+'.id'
-                where_list.append(str_where)
+                if k in self.pool.get(model)._columns:
+                    str_where = model_dict.get(model)+"."+ k + "=" + model_dict.get(v.get('relation'))+'.id'
+                    where_list.append(str_where)
         if reference_model_dict:
             self.model_set_id = model_dict.get(reference_model_dict.keys()[reference_model_dict.values().index(min(reference_model_dict.values()))])
         if model_list and not len(model_dict.keys()) == 1:
@@ -242,6 +319,7 @@ class report_creator(osv.osv):
         
             
         if where_list:
+            where_list = list(set(where_list))
             ret_str+="\n where \n"+" and\n".join(where_list)
             ret_str = ret_str.strip()
         if filter_list:
@@ -250,8 +328,8 @@ class report_creator(osv.osv):
                 ret_str = ret_str[0:len(ret_str)-3]
             if ret_str.endswith('or'):
                 ret_str = ret_str[0:len(ret_str)-2]
-            ret_str = ret_str.strip()    
-        return ret_str
+            ret_str = ret_str.strip()
+        return ret_str % {'uid' : uid}
 
     def _id_get(self, cr, uid, id, context):
 #       return 'min(sale_order_line.id)'
@@ -264,18 +342,22 @@ class report_creator(osv.osv):
             groupby = []
             i = 0
             for f in obj.field_ids:
+                # Allowing to use count(*)
+                if not f.field_id.model and f.group_method == 'count':
+                    fields.insert(0,('count(*) as column_count'))
+                    continue
                 t = self.pool.get(f.field_id.model_id.model)._table
                 if f.group_method == 'group':
                     fields.append('\t'+t+'.'+f.field_id.name+' as field'+str(i))
-                    groupby.append(t+'.'+f.field_id.name)
                 else:
                     fields.append('\t'+f.group_method+'('+t+'.'+f.field_id.name+')'+' as field'+str(i))
+                if f.group_method == 'group':
+                    groupby.append(t+'.'+f.field_id.name)
                 i+=1
             models = self._path_get(cr, uid, obj.model_ids, obj.filter_ids)
             check = self._id_get(cr, uid, ids[0], context)
             if check<>False:
                 fields.insert(0,(check+' as id'))
-            
             if models:
                 result[obj.id] = """select
     %s
@@ -323,6 +405,9 @@ class report_creator(osv.osv):
         this_objs = self.browse(cr, uid, ids)
         for obj in this_objs:
             for fld in obj.field_ids:
+                # Allowing to use count(*)
+                if not fld.field_id.model and fld.group_method == 'count':
+                    continue
                 model_column = self.pool.get(fld.field_id.model)._columns[fld.field_id.name]
                 if (isinstance(model_column,fields.function) or isinstance(model_column,fields.related)) and not model_column.store:
                     return False 
@@ -334,6 +419,9 @@ class report_creator(osv.osv):
         this_objs = self.browse(cr, uid, ids)
         for obj in this_objs:
             for fld in obj.field_ids:
+                # Allowing to use count(*)
+                if not fld.field_id.model and fld.group_method == 'count':
+                    continue
                 model_column = self.pool.get(fld.field_id.model)._columns[fld.field_id.name]                
                 if model_column._type not in aggregate_columns and fld.group_method in apply_functions:
                     return False 
@@ -346,6 +434,9 @@ class report_creator(osv.osv):
         for obj in this_objs:
             if obj.view_type1=='calendar' or obj.view_type2=='calendar' or obj.view_type3=='calendar': 
                 for fld in obj.field_ids:
+                    # Allowing to use count(*)
+                    if not fld.field_id.model and fld.group_method == 'count':
+                        continue
                     model_column = self.pool.get(fld.field_id.model)._columns[fld.field_id.name]
                     if fld.calendar_mode in ('date_start','date_end') and model_column._type not in ('date','datetime'):
                         return False
@@ -375,7 +466,7 @@ class report_creator_field(osv.osv):
         'report_id': fields.many2one('base_report_creator.report','Report', on_delete='cascade'),
         'group_method': fields.selection([('group','Grouped'),('sum','Sum'),('min','Minimum'),('count','Count'),('max','Maximum'),('avg','Average')], 'Grouping Method', required=True),
         'graph_mode': fields.selection([('','/'),('x','X Axis'),('y','Y Axis')], 'Graph Mode'),
-        'calendar_mode': fields.selection([('','/'),('date_start','Starting Date'),('date_end','Ending Date'),('date_delay','Delay'),('color','Uniq Colors')], 'Calendar Mode'),
+        'calendar_mode': fields.selection([('','/'),('date_start','Starting Date'),('date_end','Ending Date'),('date_delay','Delay'),('date_stop','End Date'),('color','Unique Colors')], 'Calendar Mode'),
     }
     _defaults = {
         'group_method': lambda *args: 'group',
