@@ -122,7 +122,7 @@ class abstracted_fs:
     def db_list(self):
         #return pooler.pool_dic.keys()
         s = netsvc.LocalService('db')
-        result = s.list()
+        result = s.list(document=True)
         self.db_name_list = []
         for db_name in result:
             db, cr = None, None
@@ -851,6 +851,7 @@ class abstracted_fs:
             if 'unique' in facts:
                 unique = "unique=%x%x;" %(st.st_dev, st.st_ino)
             path=_to_decode(file.path)
+            path = path and path.split('/')[-1] or None
             yield "%s%s%s%s%s%s%s%s%s %s\r\n" %(type, size, perm, modify, create,
                                                 mode, uid, gid, unique, path)
 
