@@ -21,3 +21,5 @@
 ##############################################################################
 
 import document
+import document_ics_config_wizard
+# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
