@@ -29,6 +29,8 @@ import datetime
 import time
 import random
 import tools
+from tools.translate import _
+import mx
 
 ICS_TAGS = {
     'summary':'normal',
@@ -110,7 +112,7 @@ class document_directory_content(osv.osv):
             if short:
                 return datetime.date.fromtimestamp(time.mktime(time.strptime(idate, '%Y-%m-%d')))
             else:
-                return datetime.datetime.strptime(idate, '%Y-%m-%d %H:%M:%S')
+                return mx.DateTime.strptime(idate, '%Y-%m-%d %H:%M:%S')
 
         import vobject
         obj_class = self.pool.get(node.content.ics_object_id.model)
@@ -128,6 +130,7 @@ class document_directory_content(osv.osv):
                 event.add('last-modified').value = ics_datetime(perm[0]['write_date'][:19])
             for field in node.content.ics_field_ids:
                 value = getattr(obj, field.field_id.name)
+                value = value and tools.ustr(value)
                 if (not value) and field.name=='uid':
                     value = 'OpenERP-%s_%s@%s' % (node.content.ics_object_id.model, str(obj.id), cr.dbname,)
                     obj_class.write(cr, uid, [obj.id], {field.field_id.name: value})
@@ -146,7 +149,7 @@ class document_directory_content(osv.osv):
                     else:
                         value = ics_datetime(value)
                     event.add(field.name).value = value
-        s= StringIO.StringIO(cal.serialize().encode('utf8'))
+        s= StringIO.StringIO(cal.serialize())
         s.name = node
         cr.commit()
         return s
