@@ -77,8 +77,8 @@ class event(osv.osv):
     def _get_register(self, cr, uid, ids, name, args, context=None):
         res={}
         for event in self.browse(cr, uid, ids, context):
-            query = """select sum(nb_register) from crm_case c left join crm_case_section s on (c.section_id=s.id) right join event_event e on (e.section_id=s.id) right join event_registration r on (r.case_id=c.id) where e.section_id = %s and c.state in ('open','done')""" % event.section_id.id
-            cr.execute(query)
+            query = """select sum(nb_register) from crm_case c left join crm_case_section s on (c.section_id=s.id) right join event_event e on (e.section_id=s.id) right join event_registration r on (r.case_id=c.id) where e.section_id = %s and c.state in ('open','done')"""
+            cr.execute(query,(event.section_id.id,))
             res2 = cr.fetchone()
             if res2 and res2[0]:
                 res[event.id] = res2[0]
@@ -89,8 +89,8 @@ class event(osv.osv):
     def _get_prospect(self, cr, uid, ids, name, args, context=None):
         res={}
         for event in self.browse(cr, uid, ids, context):
-            query = """select sum(nb_register) from crm_case c left join crm_case_section s on (c.section_id=s.id) right join event_event e on (e.section_id=s.id) right join event_registration r on (r.case_id=c.id) where e.section_id = %s and c.state = 'draft'""" % event.section_id.id
-            cr.execute(query)
+            query = """select sum(nb_register) from crm_case c left join crm_case_section s on (c.section_id=s.id) right join event_event e on (e.section_id=s.id) right join event_registration r on (r.case_id=c.id) where e.section_id = %s and c.state = 'draft'"""
+            cr.execute(query, (event.section_id.id,))
             res2 = cr.fetchone()
             if res2 and res2[0]:
                 res[event.id] = res2[0]
@@ -195,6 +195,8 @@ class event_registration(osv.osv):
         reg_ids=self.browse(cr,uid,ids)
         for reg_id in reg_ids:
             src = reg_id.event_id.reply_to or False
+            if not reg_id.email_from:
+                raise osv.except_osv(_('Warning!'), _('You should specify Partner Email for registration "%s" !')%(reg_id.name,))
             dest = [reg_id.email_from]
             if reg_id.email_cc:
                 dest += [reg_id.email_cc]
@@ -208,6 +210,8 @@ class event_registration(osv.osv):
         reg_ids=self.browse(cr,uid,ids)
         for reg_id in reg_ids:
             src = reg_id.event_id.reply_to or False
+            if not reg_id.email_from:
+                raise osv.except_osv(_('Warning!'), _('You should specify Partner Email for registration "%s" !')%(reg_id.name,))
             dest = [reg_id.email_from]
             if reg_id.email_cc:
                 dest += [reg_id.email_cc]
