@@ -44,7 +44,8 @@ class hr_department(osv.osv):
     def _check_recursion(self, cr, uid, ids):
         level = 100
         while len(ids):
-            cr.execute('select distinct parent_id from hr_department where id in ('+','.join(map(str,ids))+')')
+            cr.execute('SELECT DISTINCT parent_id FROM hr_department '\
+                       'WHERE id IN %s', (tuple(ids),))
             ids = filter(None, map(lambda x:x[0], cr.fetchall()))
             if not level:
                 return False
@@ -112,7 +113,7 @@ class res_users(osv.osv):
                 child_ids.extend(tools.flatten(childs))
         return child_ids
 
-    def _parent_search(self, cr, uid, obj, name, args):
+    def _parent_search(self, cr, uid, obj, name, args, context):
         parent = []
         for arg in args:
             if arg[0] == 'parent_id':
@@ -128,4 +129,4 @@ class res_users(osv.osv):
 
 res_users()
 
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
\ No newline at end of file
+# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
