@@ -104,7 +104,7 @@ class hr_timesheet_sheet(osv.osv):
                 LEFT JOIN hr_timesheet_sheet_sheet_day AS day \
                     ON (sheet.id = day.sheet_id \
                         AND day.name = sheet.date_current) \
-                WHERE sheet.id in (' + ','.join([str(x) for x in ids]) + ')')
+                WHERE sheet.id in %s', (tuple(ids),))
         return dict(cr.fetchall())
 
     def _total(self, cr, uid, ids, name, args, context):
@@ -112,8 +112,8 @@ class hr_timesheet_sheet(osv.osv):
                 FROM hr_timesheet_sheet_sheet s \
                     LEFT JOIN hr_timesheet_sheet_sheet_day d \
                         ON (s.id = d.sheet_id) \
-                WHERE s.id in ('+ ','.join(map(str, ids)) + ') \
-                GROUP BY s.id')
+                WHERE s.id in %s \
+                GROUP BY s.id', (tuple(ids),))
         return dict(cr.fetchall())
 
     def _state_attendance(self, cr, uid, ids, name, args, context):
@@ -300,9 +300,12 @@ class hr_timesheet_sheet(osv.osv):
                     context, load='_classic_write')]
 
     def unlink(self, cr, uid, ids, context=None):
-        sheets = self.read(cr, uid, ids, ['state'])
-        if any(s['state'] in ('confirm', 'done') for s in sheets):
-            raise osv.except_osv(_('Invalid action !'), _('Cannot delete Sheet(s) which are already confirmed !'))
+        sheets = self.read(cr, uid, ids, ['state','total_attendance'])
+        for sheet in sheets:
+            if sheet['state'] in ('confirm', 'done'):
+                raise osv.except_osv(_('Invalid action !'), _('Cannot delete Sheet(s) which are already confirmed !'))
+            elif sheet['total_attendance'] <> 0.00:
+                raise osv.except_osv(_('Invalid action !'), _('Cannot delete Sheet(s) which have attendance entries encoded !'))
         return super(hr_timesheet_sheet, self).unlink(cr, uid, ids, context=context)
 
 hr_timesheet_sheet()
@@ -327,8 +330,8 @@ class hr_timesheet_line(osv.osv):
                         ON (s.date_to >= al.date \
                             AND s.date_from <= al.date \
                             AND s.user_id = al.user_id) \
-                WHERE l.id in (' + ','.join([str(x) for x in ids]) + ') \
-                GROUP BY l.id')
+                WHERE l.id in %s \
+                GROUP BY l.id', (tuple(ids),))
         res = dict(cursor.fetchall())
         sheet_names = {}
         for sheet_id, name in sheet_obj.name_get(cursor, user, res.values(),
@@ -343,7 +346,7 @@ class hr_timesheet_line(osv.osv):
                 res[line_id] = False
         return res
 
-    def _sheet_search(self, cursor, user, obj, name, args):
+    def _sheet_search(self, cursor, user, obj, name, args, context=None):
         if not len(args):
             return []
         sheet_obj = self.pool.get('hr_timesheet_sheet.sheet')
@@ -445,8 +448,8 @@ class hr_attendance(osv.osv):
                         ON (s.date_to >= to_date(to_char(a.name, 'YYYY-MM-dd'),'YYYY-MM-dd') \
                             AND s.date_from <= to_date(to_char(a.name, 'YYYY-MM-dd'),'YYYY-MM-dd') \
                             AND s.user_id = e.user_id) \
-                WHERE a.id in (" + ",".join([str(x) for x in ids]) + ") \
-                GROUP BY a.id")
+                WHERE a.id in %s \
+                GROUP BY a.id", (tuple(ids),))
         res = dict(cursor.fetchall())
         sheet_names = {}
         for sheet_id, name in sheet_obj.name_get(cursor, user, res.values(),
@@ -460,7 +463,7 @@ class hr_attendance(osv.osv):
                 res[line_id] = False
         return res
 
-    def _sheet_search(self, cursor, user, obj, name, args):
+    def _sheet_search(self, cursor, user, obj, name, args, context=None):
         if not len(args):
             return []
         sheet_obj = self.pool.get('hr_timesheet_sheet.sheet')
