@@ -61,7 +61,7 @@ class mrp_procurement(osv.osv):
             cr.execute('select id from mrp_procurement where state=%s and procure_method=%s order by date_planned limit 500 offset %s', ('confirmed', 'make_to_order', offset))
             ids = map(lambda x: x[0], cr.fetchall())
             for proc in procurement_obj.browse(cr, uid, ids):
-                if (maxdate.strftime('%Y-%m-%d')>=proc.date_planned)  or (proc.procure_method=='make_to_order'):
+                if (maxdate.strftime('%Y-%m-%d')>=proc.date_planned):
                     wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
                 else:
                     offset += 1
@@ -84,7 +84,7 @@ class mrp_procurement(osv.osv):
             report_ids = []
             ids = self.pool.get('mrp.procurement').search(cr, uid, [('state', '=', 'confirmed'), ('procure_method', '=', 'make_to_stock')], offset=offset)
             for proc in procurement_obj.browse(cr, uid, ids):
-                if ((maxdate).strftime('%Y-%m-%d') >= proc.date_planned) or (proc.procure_method=='make_to_order'):
+                if ((maxdate).strftime('%Y-%m-%d') >= proc.date_planned) :
                     wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
                     report_ids.append(proc.id)
                 else:
@@ -198,7 +198,7 @@ class mrp_procurement(osv.osv):
                     if reste > 0:
                         qty += op.qty_multiple - reste
                     newdate = DateTime.now() + DateTime.RelativeDateTime(
-                            days=op.product_id.seller_delay)
+                            days=int(op.product_id.seller_delay))
                     if op.product_id.supply_method == 'buy':
                         location_id = op.warehouse_id.lot_input_id
                     elif op.product_id.supply_method == 'produce':
