@@ -29,7 +29,7 @@ from tools.translate import _
 class pos_invoice(report_sxw.rml_parse):
 
     def __init__(self, cr, uid, name, context):
-        super(pos_invoice, self).__init__(cr, uid, name, context)
+        super(pos_invoice, self).__init__(cr, uid, name, context=context)
         self.localcontext.update({
             'time': time,
         })
