@@ -64,10 +64,11 @@ class project(osv.osv):
                 FROM
                     project_task 
                 WHERE
-                    project_id in ('''+','.join(map(str,ids2))+''') AND
+                    project_id in %s AND
                     state<>'cancelled'
                 GROUP BY
-                    project_id''')
+                    project_id''',
+                       (tuple(ids2),))
             progress = dict(map(lambda x: (x[0], (x[1],x[2],x[3])), cr.fetchall()))
         for project in self.browse(cr, uid, ids, context=context):
             s = [0.0,0.0,0.0]
@@ -166,7 +167,7 @@ class project(osv.osv):
             default['name'] = proj.name+_(' (copy)')
         res = super(project, self).copy(cr, uid, id, default, context)
         ids = self.search(cr, uid, [('parent_id','child_of', [res])])
-        cr.execute('update project_task set active=True where project_id in ('+','.join(map(str,ids))+')')
+        cr.execute('update project_task set active=True where project_id in %s', (tuple(ids),))
         return res
 
     def duplicate_template(self, cr, uid, ids,context={}):
@@ -228,8 +229,7 @@ class task(osv.osv):
 
 # Compute: effective_hours, total_hours, progress
     def _hours_get(self, cr, uid, ids, field_names, args, context):
-        task_set = ','.join(map(str, ids))
-        cr.execute(("SELECT task_id, COALESCE(SUM(hours),0) FROM project_task_work WHERE task_id in (%s) GROUP BY task_id") % (task_set,))
+        cr.execute("SELECT task_id, COALESCE(SUM(hours),0) FROM project_task_work WHERE task_id in %s GROUP BY task_id", (tuple(ids),))
         hours = dict(cr.fetchall())
         res = {}
         for task in self.browse(cr, uid, ids, context=context):
@@ -306,12 +306,14 @@ class task(osv.osv):
     # Override view according to the company definition
     #
     def fields_view_get(self, cr, uid, view_id=None, view_type='form', context=None, toolbar=False):
-        tm = self.pool.get('res.users').browse(cr, uid, uid, context).company_id.project_time_mode
+        tm = self.pool.get('res.users').browse(cr, uid, uid, context).company_id.project_time_mode or False
         f = self.pool.get('res.company').fields_get(cr, uid, ['project_time_mode'], context)
-        word = dict(f['project_time_mode']['selection'])[tm]
+        word = 'Hours'
+        if tm:
+            word = dict(f['project_time_mode']['selection'])[tm]
 
         res = super(task, self).fields_view_get(cr, uid, view_id, view_type, context, toolbar)
-        if tm=='hours':
+        if (not tm) or (tm=='hours'):
             return res
         eview = etree.fromstring(res['arch'])
         def _check_rec(eview, tm):
