@@ -65,7 +65,7 @@ class report_intrastat(osv.osv):
         'name': fields.many2one('account.period', 'Period', readonly=True, select=True),
         'supply_units':fields.float('Supply Units', readonly=True),
         'ref':fields.char('Origin',size=64, readonly=True),
-        'code': fields.char('Country code', size="2", readonly=True),
+        'code': fields.char('Country code', size=2, readonly=True),
         'intrastat_id': fields.many2one('report.intrastat.code', 'Intrastat code', readonly=True),
         'weight': fields.float('Weight', readonly=True),
         'value': fields.float('Value', readonly=True),
