@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 ##############################################################################
 #
@@ -37,18 +37,6 @@ GNU Public Licence.
 import sys
 import os
 import signal
-#----------------------------------------------------------
-# ubuntu 8.04 has obsoleted `pyxml` package and installs here.
-# the path needs to be updated before any `import xml`
-# TODO: remove PyXML dependencies, use lxml instead.
-#----------------------------------------------------------
-_oldxml1 = '/usr/lib/python%s/site-packages/oldxml' % sys.version[:3]
-_oldxml2 = '/usr/lib/python%s/dist-packages/oldxml' % sys.version[:3]
-if os.path.exists(_oldxml1):
-    sys.path.insert(0,_oldxml1)
-elif os.path.exists(_oldxml2):
-    sys.path.insert(0,_oldxml2)    
-
 
 import release
 __author__ = release.author
