@@ -32,15 +32,12 @@
 #   required
 #   size
 #
-import string
-import netsvc
-import sys
 
 from psycopg2 import Binary
 import warnings
 
 import tools
-
+from tools.translate import _
 
 def _symbol_set(symb):
     if symb == None or symb == False:
@@ -99,9 +96,9 @@ class _column(object):
     def get(self, cr, obj, ids, name, user=None, offset=0, context=None, values=None):
         raise Exception(_('undefined get method !'))
 
-    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None):
-        ids = obj.search(cr, uid, args+self._domain+[(name, 'ilike', value)], offset, limit)
-        res = obj.read(cr, uid, ids, [name])
+    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, context=None):
+        ids = obj.search(cr, uid, args+self._domain+[(name, 'ilike', value)], offset, limit, context=context)
+        res = obj.read(cr, uid, ids, [name], context=context)
         return [x[name] for x in res]
 
     def search_memory(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, context=None):
@@ -267,8 +264,8 @@ class one2one(_column):
             id = cr.fetchone()[0]
             obj.write(cr, user, [id], act[1], context=context)
 
-    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None):
-        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', 'like', value)], offset, limit)
+    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, context=None):
+        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', 'like', value)], offset, limit, context=context)
 
 
 class many2one(_column):
@@ -306,14 +303,16 @@ class many2one(_column):
         obj = obj.pool.get(self._obj)
         # build a dictionary of the form {'id_of_distant_resource': name_of_distant_resource}
         from orm import except_orm
-        try:
-            names = dict(obj.name_get(cr, user, filter(None, res.values()), context))
-        except except_orm:
-            names = {}
-            iids = filter(None, res.values())
-            for iiid in iids:
-                names[iiid] = '// Access Denied //'
 
+        names = {}
+        for record in list(set(filter(None, res.values()))):
+            try:
+                record_name = dict(obj.name_get(cr, user, [record], context))
+            except except_orm:
+                record_name = {}
+                record_name[record] = '// Access Denied //'
+            names.update(record_name)        
+        
         for r in res.keys():
             if res[r] and res[r] in names:
                 res[r] = (res[r], names[res[r]])
@@ -345,8 +344,8 @@ class many2one(_column):
             else:
                 cr.execute('update '+obj_src._table+' set '+field+'=null where id=%s', (id,))
 
-    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None):
-        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', 'like', value)], offset, limit)
+    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, context=None):
+        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', 'like', value)], offset, limit, context=context)
 
 
 class one2many(_column):
@@ -458,13 +457,13 @@ class one2many(_column):
             elif act[0] == 6:
                 obj.write(cr, user, act[2], {self._fields_id:id}, context=context or {})
                 ids2 = act[2] or [0]
-                cr.execute('select id from '+_table+' where '+self._fields_id+'=%s and id not in ('+','.join(map(str, ids2))+')', (id,))
+                cr.execute('select id from '+_table+' where '+self._fields_id+'=%s and id not in %s', (id, tuple(ids2)))
                 ids3 = map(lambda x:x[0], cr.fetchall())
                 obj.write(cr, user, ids3, {self._fields_id:False}, context=context or {})
         return result
 
-    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, operator='like'):
-        return obj.pool.get(self._obj).name_search(cr, uid, value, self._domain, offset, limit)
+    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, operator='like', context=None):
+        return obj.pool.get(self._obj).name_search(cr, uid, value, self._domain, operator, context=context,limit=limit)
 
 
 #
@@ -503,7 +502,6 @@ class many2many(_column):
             return res
         for id in ids:
             res[id] = []
-        ids_s = ','.join(map(str, ids))
         limit_str = self._limit is not None and ' limit %d' % self._limit or ''
         obj = obj.pool.get(self._obj)
 
@@ -511,12 +509,25 @@ class many2many(_column):
         if d1:
             d1 = ' and ' + d1
 
-        cr.execute('SELECT '+self._rel+'.'+self._id2+','+self._rel+'.'+self._id1+' \
-                FROM '+self._rel+' , '+obj._table+' \
-                WHERE '+self._rel+'.'+self._id1+' in ('+ids_s+') \
-                    AND '+self._rel+'.'+self._id2+' = '+obj._table+'.id '+d1
-                +limit_str+' order by '+obj._table+'.'+obj._order+' offset %s',
-                d2+[offset])
+        query = 'SELECT %(rel)s.%(id2)s, %(rel)s.%(id1)s \
+                   FROM %(rel)s, %(tbl)s \
+                  WHERE %(rel)s.%(id1)s in %%s \
+                    AND %(rel)s.%(id2)s = %(tbl)s.id \
+                 %(d1)s  \
+                 %(limit)s \
+                  ORDER BY %(tbl)s.%(order)s \
+                 OFFSET %(offset)d' \
+            % {'rel': self._rel,
+               'tbl': obj._table,
+               'id1': self._id1,
+               'id2': self._id2,
+               'd1': d1,
+               'limit': limit_str,
+               'order': obj._order,
+               'offset': offset,
+              }
+
+        cr.execute(query, [tuple(ids)] + d2)
         for r in cr.fetchall():
             res[r[1]].append(r[0])
         return res
@@ -528,6 +539,8 @@ class many2many(_column):
             return
         obj = obj.pool.get(self._obj)
         for act in values:
+            if not (isinstance(act, list) or isinstance(act, tuple)) or not act:
+                continue
             if act[0] == 0:
                 idnew = obj.create(cr, user, act[2])
                 cr.execute('insert into '+self._rel+' ('+self._id1+','+self._id2+') values (%s,%s)', (id, idnew))
@@ -554,8 +567,8 @@ class many2many(_column):
     #
     # TODO: use a name_search
     #
-    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, operator='like'):
-        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', operator, value)], offset, limit)
+    def search(self, cr, obj, args, name, value, offset=0, limit=None, uid=None, operator='like', context=None):
+        return obj.pool.get(self._obj).search(cr, uid, args+self._domain+[('name', operator, value)], offset, limit, context=context)
 
     def get_memory(self, cr, obj, ids, name, user=None, offset=0, context=None, values=None):
         result = {}
@@ -630,11 +643,11 @@ class function(_column):
             self._symbol_f = float._symbol_f
             self._symbol_set = float._symbol_set
 
-    def search(self, cr, uid, obj, name, args):
+    def search(self, cr, uid, obj, name, args, context=None):
         if not self._fnct_search:
             #CHECKME: should raise an exception
             return []
-        return self._fnct_search(obj, cr, uid, obj, name, args)
+        return self._fnct_search(obj, cr, uid, obj, name, args, context=context)
 
     def get(self, cr, obj, ids, name, user=None, context=None, values=None):
         if not context:
@@ -696,45 +709,43 @@ class related(function):
     def _fnct_write(self,obj,cr, uid, ids, field_name, values, args, context=None):
         if values and field_name:
             self._field_get2(cr, uid, obj, context)
-            relation = obj._name
-            res = {}
             if type(ids) != type([]):
                 ids=[ids]
             objlst = obj.browse(cr, uid, ids)
             for data in objlst:
-                t_id=None
+                t_id = None
                 t_data = data
-                relation = obj._name
                 for i in range(len(self.arg)):
                     field_detail = self._relations[i]
-                    relation = field_detail['object']
                     if not t_data[self.arg[i]]:
+                        if self._type not in ('one2many', 'many2many'):
+                            t_id = t_data['id']
                         t_data = False
                         break
                     if field_detail['type'] in ('one2many', 'many2many'):
                         if self._type != "many2one":
-                            t_id=t_data.id
+                            t_id = t_data.id
                             t_data = t_data[self.arg[i]][0]
+                        else:
+                            t_data = False
+                            break
                     else:
-                        t_id=t_data['id']
+                        t_id = t_data['id']
                         t_data = t_data[self.arg[i]]
-                if t_id:
-                    obj.pool.get(field_detail['object']).write(cr,uid,[t_id],{args[-1]:values})
+                if t_id and t_data:
+                    obj.pool.get(field_detail['object']).write(cr,uid,[t_id],{args[-1]:values}, context=context)
 
     def _fnct_read(self, obj, cr, uid, ids, field_name, args, context=None):
         self._field_get2(cr, uid, obj, context)
         if not ids: return {}
-        relation = obj._name
         res = {}.fromkeys(ids, False)
         objlst = obj.browse(cr, uid, ids)
         for data in objlst:
             if not data:
                 continue
             t_data = data
-            relation = obj._name
             for i in range(len(self.arg)):
                 field_detail = self._relations[i]
-                relation = field_detail['object']
                 try:
                     if not t_data[self.arg[i]]:
                         t_data = False
@@ -742,7 +753,7 @@ class related(function):
                 except:
                     t_data = False
                     break
-                if field_detail['type'] in ('one2many', 'many2many'):
+                if field_detail['type'] in ('one2many', 'many2many') and i != len(self.arg) - 1:
                     t_data = t_data[self.arg[i]][0]
                 else:
                     t_data = t_data[self.arg[i]]
@@ -758,6 +769,11 @@ class related(function):
                 for r in res:
                     if res[r]:
                         res[r] = (res[r], ng[res[r]])
+        elif self._type in ('one2many', 'many2many'):
+            for r in res:
+                if res[r]:
+                    res[r] = [x.id for x in res[r]]
+
         return res
 
     def __init__(self, *arg, **args):
