@@ -29,16 +29,16 @@ import netsvc
 import pooler
 import copy
 import sys
+import traceback
 
 from psycopg2 import IntegrityError
-from netsvc import Logger, LOG_ERROR
-from tools.misc import UpdateableDict
+from tools.func import wraps
+
 
 module_list = []
 module_class_list = {}
 class_pool = {}
 
-
 class except_osv(Exception):
     def __init__(self, name, value, exc_type='warning'):
         self.name = name
@@ -47,7 +47,6 @@ class except_osv(Exception):
         self.args = (exc_type, name)
 
 
-from tools.func import wraps
 class osv_pool(netsvc.Service):
    
     def check(f):
@@ -58,6 +57,9 @@ class osv_pool(netsvc.Service):
                     raise except_osv('Database not ready', 'Currently, this database is not fully loaded and can not be used.')
                 return f(self, dbname, *args, **kwargs)
             except orm.except_orm, inst:
+                if inst.name == 'AccessError':
+                    tb_s = "AccessError\n" + "".join(traceback.format_exception(*sys.exc_info()))
+                    self.logger.notifyChannel('web-services', netsvc.LOG_DEBUG, tb_s)
                 self.abortResponse(1, inst.name, 'warning', inst.value)
             except except_osv, inst:
                 self.abortResponse(1, inst.name, inst.exc_type, inst.value)
@@ -67,10 +69,8 @@ class osv_pool(netsvc.Service):
                         self.abortResponse(1, 'Constraint Error', 'warning', self._sql_error[key])
                 self.abortResponse(1, 'Integrity Error', 'warning', inst[0])
             except Exception, e:
-                import traceback, sys
                 tb_s = "".join(traceback.format_exception(*sys.exc_info()))
-                logger = Logger()
-                logger.notifyChannel('web-services', LOG_ERROR, tb_s)
+                self.logger.notifyChannel('web-services', netsvc.LOG_ERROR, tb_s)
                 raise
 
         return wrapper
@@ -85,6 +85,7 @@ class osv_pool(netsvc.Service):
         self._store_function = {}
         self._init = True
         self._init_parent = {}
+        self.logger = netsvc.Logger()
         netsvc.Service.__init__(self, 'object_proxy', audience='')
         self.exportMethod(self.obj_list)
         self.exportMethod(self.exec_workflow)
@@ -239,7 +240,8 @@ class osv(orm.orm):
                         for c in cls.__dict__.get(s, []):
                             exist = False
                             for c2 in range(len(new)):
-                                if new[c2][2]==c[2]:
+                                #For _constraints, we should check field and methods as well
+                                if new[c2][2]==c[2] and new[c2][0]==c[0]:
                                     new[c2] = c
                                     exist = True
                                     break
