@@ -33,12 +33,11 @@ from osv.osv import except_osv
 from osv.orm import browse_null
 from osv.orm import browse_record_list
 import pooler
-from xml.dom import minidom
-import libxml2
-import libxslt
 from pychart import *
 import misc
 import cStringIO
+from lxml import etree
+from tools.translate import _
 
 class external_pdf(render.render):
     def __init__(self, pdf):
@@ -287,17 +286,13 @@ class report_custom(report_int):
         if report['print_orientation']=='landscape':
             pageSize=[pageSize[1],pageSize[0]]
 
-        impl = minidom.getDOMImplementation()
-        new_doc = impl.createDocument(None, "report", None)
+        new_doc = etree.Element('report')
         
-        # build header
-        config = new_doc.createElement("config")
+        config = etree.SubElement(new_doc, 'config')
 
         def _append_node(name, text):
-            n = new_doc.createElement(name)
-            t = new_doc.createTextNode(text)
-            n.appendChild(t)
-            config.appendChild(n)
+            n = etree.SubElement(config, name)
+            n.text = text
 
         _append_node('date', time.strftime('%d/%m/%Y'))
         _append_node('PageFormat', '%s' % report['print_format'])
@@ -317,45 +312,33 @@ class report_custom(report_int):
         _append_node('report-header', '%s' % (report['title'],))
         _append_node('report-footer', '%s' % (report['footer'],))
 
-        new_doc.childNodes[0].appendChild(config)
-        header = new_doc.createElement("header")
-        
+        header = etree.SubElement(new_doc, 'header')
         for f in fields:
-            field = new_doc.createElement("field")
-            field_txt = new_doc.createTextNode('%s' % (f['name'],))
-            field.appendChild(field_txt)
-            header.appendChild(field)
-        
-        new_doc.childNodes[0].appendChild(header)
+            field = etree.SubElement(header, 'field')
+            field.text = f['name']
 
-        lines = new_doc.createElement("lines")
+        lines = etree.SubElement(new_doc, 'lines')
         level.reverse()
         for line in results:
             shift = level.pop()
-            node_line = new_doc.createElement("row")
+            node_line = etree.SubElement(lines, 'row')
             prefix = '+'
             for f in range(len(fields)):
-                col = new_doc.createElement("col")
+                col = etree.SubElement(node_line, 'col')
                 if f == 0:
-                    col.setAttribute('para','yes')
-                    col.setAttribute('tree','yes')
-                    col.setAttribute('space',str(3*shift)+'mm')
+                    col.attrib.update(para='yes',
+                                      tree='yes',
+                                      space=str(3*shift)+'mm')
                 if line[f] != None:
-                    txt = new_doc.createTextNode(prefix+str(line[f]) or '')
+                    col.text = prefix+str(line[f]) or ''
                 else:
-                    txt = new_doc.createTextNode('/')
-                col.appendChild(txt)
-                node_line.appendChild(col)
+                    col.text = '/'
                 prefix = ''
-            lines.appendChild(node_line)
-            
-        new_doc.childNodes[0].appendChild(lines)
 
-        styledoc = libxml2.parseFile(os.path.join(tools.config['root_path'],'addons/base/report/custom_new.xsl'))
-        style = libxslt.parseStylesheetDoc(styledoc)
-        doc = libxml2.parseDoc(new_doc.toxml())
-        rml_obj = style.applyStylesheet(doc, None)
-        rml = style.saveResultToString(rml_obj) 
+        transform = etree.XSLT(
+            etree.parse(os.path.join(tools.config['root_path'],
+                                     'addons/base/report/custom_new.xsl')))
+        rml = etree.tostring(transform(new_doc))
 
         self.obj = render.rml(rml)
         self.obj.render()
@@ -592,17 +575,12 @@ class report_custom(report_int):
         if report['print_orientation']=='landscape':
             pageSize=[pageSize[1],pageSize[0]]
 
-        impl = minidom.getDOMImplementation()
-        new_doc = impl.createDocument(None, "report", None)
-        
-        # build header
-        config = new_doc.createElement("config")
+        new_doc = etree.Element('report')
+        config = etree.SubElement(new_doc, 'config')
 
         def _append_node(name, text):
-            n = new_doc.createElement(name)
-            t = new_doc.createTextNode(text)
-            n.appendChild(t)
-            config.appendChild(n)
+            n = etree.SubElement(config, name)
+            n.text = text
 
         _append_node('date', time.strftime('%d/%m/%Y'))
         _append_node('PageSize', '%.2fmm,%.2fmm' % tuple(pageSize))
@@ -622,40 +600,25 @@ class report_custom(report_int):
         _append_node('report-header', '%s' % (report['title'],))
         _append_node('report-footer', '%s' % (report['footer'],))
 
-        new_doc.childNodes[0].appendChild(config)
-        header = new_doc.createElement("header")
-        
+        header = etree.SubElement(new_doc, 'header')
         for f in fields:
-            field = new_doc.createElement("field")
-            field_txt = new_doc.createTextNode('%s' % (f['name'],))
-            field.appendChild(field_txt)
-            header.appendChild(field)
-        
-        new_doc.childNodes[0].appendChild(header)
+            field = etree.SubElement(header, 'field')
+            field.text = f['name']
 
-        lines = new_doc.createElement("lines")
+        lines = etree.SubElement(new_doc, 'lines')
         for line in results:
-            node_line = new_doc.createElement("row")
+            node_line = etree.SubElement(lines, 'row')
             for f in range(len(fields)):
-                col = new_doc.createElement("col")
-                col.setAttribute('tree','no')
+                col = etree.SubElement(node_line, 'col', tree='no')
                 if line[f] != None:
-                    txt = new_doc.createTextNode(str(line[f] or ''))
+                    col.text = line[f] or ''
                 else:
-                    txt = new_doc.createTextNode('/')
-                col.appendChild(txt)
-                node_line.appendChild(col)
-            lines.appendChild(node_line)    
-            
-        new_doc.childNodes[0].appendChild(lines)
+                    col.text = '/'
 
-#       file('/tmp/terp.xml','w+').write(new_doc.toxml())
-
-        styledoc = libxml2.parseFile(os.path.join(tools.config['root_path'],'addons/base/report/custom_new.xsl'))
-        style = libxslt.parseStylesheetDoc(styledoc)
-        doc = libxml2.parseDoc(new_doc.toxml())
-        rml_obj = style.applyStylesheet(doc, None)
-        rml = style.saveResultToString(rml_obj) 
+        transform = etree.XSLT(
+            etree.parse(os.path.join(tools.config['root_path'],
+                                     'addons/base/report/custom_new.xsl')))
+        rml = etree.tostring(transform(new_doc))
 
         self.obj = render.rml(rml)
         self.obj.render()
