@@ -25,8 +25,6 @@ import pooler
 import tools
 from lxml  import etree
 from report import render
-import libxml2
-import libxslt
 import locale
 
 import time, os
@@ -38,14 +36,9 @@ class report_printscreen_list(report_int):
 
     def _parse_node(self, root_node):
         result = []
-        for node in root_node.getchildren():
+        for node in root_node:
             if node.tag == 'field':
-                attrsa = node.attrib
-                attrs = {}
-                if not attrsa is None:
-                   for key,val in attrsa.items():
-                    attrs[key] = val
-                result.append(attrs['name'])
+                result.append(node.get('name'))
             else:
                 result.extend(self._parse_node(node))
         return result
@@ -91,30 +84,28 @@ class report_printscreen_list(report_int):
 
     def _create_table(self, uid, ids, fields, fields_order, results, context, title=''):
         pageSize=[297.0, 210.0]
-        new_doc = etree.Element("report")
-        config = etree.Element("config")
 
-        # build header
+        new_doc = etree.Element("report")
+        config = etree.SubElement(new_doc, 'config')
 
         def _append_node(name, text):
-            n = etree.Element(name)
+            n = etree.SubElement(config, name)
             n.text = text
-            config.append(n)
 
         #_append_node('date', time.strftime('%d/%m/%Y'))
         _append_node('date', time.strftime(str(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y'))))
         _append_node('PageSize', '%.2fmm,%.2fmm' % tuple(pageSize))
         _append_node('PageWidth', '%.2f' % (pageSize[0] * 2.8346,))
         _append_node('PageHeight', '%.2f' %(pageSize[1] * 2.8346,))
-
         _append_node('report-header', title)
+
         l = []
         t = 0
         rowcount=0;
         strmax = (pageSize[0]-40) * 2.8346
         temp = []
         count = len(fields_order)
-        for i in range(0,count):
+        for i in range(0, count):
             temp.append(0)
 
         ince = -1;
@@ -136,24 +127,20 @@ class report_printscreen_list(report_int):
                 l[pos] = strmax * s / t
 
         _append_node('tableSize', ','.join(map(str,l)) )
-        new_doc.append(config)
-        header=etree.Element("header")
-
 
+        header = etree.SubElement(new_doc, 'header')
         for f in fields_order:
-            field = etree.Element("field")
+            field = etree.SubElement(header, 'field')
             field.text = tools.ustr(fields[f]['string'] or '')
-            header.append(field)
 
-        new_doc.append(header)
-        lines = etree.Element("lines")
+        lines = etree.SubElement(new_doc, 'lines')
         tsum = []
         count = len(fields_order)
         for i in range(0,count):
             tsum.append(0)
             
         for line in results:
-            node_line = etree.Element("row")
+            node_line = etree.SubElement(lines, 'row')
             count = -1
             for f in fields_order:
                 float_flag = 0
@@ -195,28 +182,19 @@ class report_printscreen_list(report_int):
                     new_d1 = d1.strftime(format)
                     line[f] = new_d1
                     
-                col = etree.Element("col")
-                col.set('para','yes')
-                col.set('tree','no')
+                col = etree.SubElement(node_line, 'col', para='yes', tree='no')
                 if line[f] != None:
                     col.text = tools.ustr(line[f] or '')
                     if float_flag:
                        col.set('tree','float') 
                     if temp[count] == 1:
                         tsum[count] = float(tsum[count])  + float(line[f]);
-                        
-                        
                 else:
                      col.text = '/'
-                node_line.append(col)
-            lines.append(node_line)
-        node_line = etree.Element("row")
-        lines.append(node_line)
 
+        node_line = etree.SubElement(lines, 'row')
         for f in range(0,count+1):
-            col = etree.Element("col")
-            col.set('para','yes')
-            col.set('tree','no')
+            col = etree.SubElement(node_line, 'col', para='yes', tree='no')
             if tsum[f] != None:
                if tsum[f] >= 0.01 :
                    prec = '%.' +  str(tools.config['price_accuracy'])  + 'f'
@@ -231,16 +209,12 @@ class report_printscreen_list(report_int):
                 txt ='Total'
 
             col.text = tools.ustr(txt or '')
-            node_line.append(col)
 
-        lines.append(node_line)
+        transform = etree.XSLT(
+            etree.parse(os.path.join(tools.config['root_path'],
+                                     'addons/base/report/custom_new.xsl')))
+        rml = etree.tostring(transform(new_doc))
 
-        new_doc.append(lines)
-        styledoc = libxml2.parseFile(os.path.join(tools.config['root_path'],'addons/base/report/custom_new.xsl'))
-        style = libxslt.parseStylesheetDoc(styledoc)
-        doc = libxml2.parseDoc(etree.tostring(new_doc))
-        rml_obj = style.applyStylesheet(doc, None)
-        rml = style.saveResultToString(rml_obj)
         self.obj = render.rml(rml, title=self.title)
         self.obj.render()
         return True
