@@ -53,13 +53,20 @@ class _rml_styles(object,):
     def __init__(self, nodes, localcontext):
         self.localcontext = localcontext
         self.styles = {}
+        self.styles_obj = {}
         self.names = {}
         self.table_styles = {}
+        self.default_style = reportlab.lib.styles.getSampleStyleSheet()
+
         for node in nodes:
             for style in node.findall('blockTableStyle'):
                 self.table_styles[style.get('id')] = self._table_style_get(style)
             for style in node.findall('paraStyle'):
-                self.styles[style.get('name')] = self._para_style_update(style)
+                sname = style.get('name')
+                self.styles[sname] = self._para_style_update(style)
+            
+                self.styles_obj[sname] = reportlab.lib.styles.ParagraphStyle(sname, self.default_style["Normal"], **self.styles[sname])
+
             for variable in node.findall('initialize'):
                 for name in variable.findall('name'):
                     self.names[ name.get('id')] = name.get('value')
@@ -88,7 +95,7 @@ class _rml_styles(object,):
 
     def _table_style_get(self, style_node):
         styles = []
-        for node in style_node.getchildren():
+        for node in style_node:
             start = utils.tuple_int_get(node, 'start', (0,0) )
             stop = utils.tuple_int_get(node, 'stop', (-1,-1) )
             if node.tag=='blockValign':
@@ -127,17 +134,19 @@ class _rml_styles(object,):
 
     def para_style_get(self, node):
         style = False
-        if node.get('style'):
-            if node.get('style') in self.styles:
-                styles = reportlab.lib.styles.getSampleStyleSheet()
-                sname = node.get('style')
-                style = reportlab.lib.styles.ParagraphStyle(sname, styles["Normal"], **self.styles[sname])
+        sname = node.get('style')
+        if sname:
+            if sname in self.styles_obj:
+                style = self.styles_obj[sname]
             else:
                 sys.stderr.write('Warning: style not found, %s - setting default!\n' % (node.get('style'),) )
         if not style:
-            styles = reportlab.lib.styles.getSampleStyleSheet()
-            style = copy.deepcopy(styles['Normal'])
-        style.__dict__.update(self._para_style_update(node))
+            style = self.default_style['Normal']
+        para_update = self._para_style_update(node)
+        if para_update:
+            # update style only is necessary
+            style = copy.deepcopy(style)
+            style.__dict__.update(para_update)
         return style
 
 class _rml_doc(object):
@@ -166,7 +175,7 @@ class _rml_doc(object):
 
     def _textual_image(self, node):
         rc = ''
-        for n in node.getchildren():
+        for n in node:
             rc +=( etree.tostring(n) or '') + n.tail
         return base64.decodestring(node.tostring())
 
@@ -455,10 +464,10 @@ class _rml_flowable(object):
                 if key in ('rml_except', 'rml_loop', 'rml_tag'):
                     del txt_n.attrib[key]
             if True or not self._textual(n).isspace():
-                txt_n.text = utils.xml2str(self._textual(n))
-                txt_n.tail = ''
+                if not n.tag == 'bullet':
+                    txt_n.text = utils.xml2str(self._textual(n))
+                txt_n.tail = n.tail and utils._process_text(self, n.tail.replace('\n','')) or ''
                 rc1 += etree.tostring(txt_n)
-        #rc1 += utils._process_text(self, node.tail or '')
         return rc1
 
     def _table(self, node):
@@ -538,7 +547,7 @@ class _rml_flowable(object):
     def _illustration(self, node):
         class Illustration(platypus.flowables.Flowable):
             def __init__(self, node, localcontext, styles, self2):
-                self.localcontext = localcontext
+                self.localcontext = localcontext.copy()
                 self.node = node
                 self.styles = styles
                 self.width = utils.unit_get(node.get('width'))
@@ -749,7 +758,8 @@ class _rml_template(object):
                     frame.lastFrame = True
                 frames.append( frame )
             try :
-                gr = pt.findall('pageGraphics') or pt.getchildren()[1].findall('pageGraphics')
+                gr = pt.findall('pageGraphics')\
+                    or pt[1].findall('pageGraphics')
             except :
                 gr=''
             if len(gr):
