@@ -42,6 +42,9 @@ import reportlab
 from lxml import etree
 import copy
 import tools
+import locale
+import netsvc
+import traceback, sys
 
 _regex = re.compile('\[\[(.+?)\]\]')
 
@@ -53,7 +56,7 @@ def xml2str(s):
 
 def _child_get(node, self=None, tagname=None):
     for n in node:
-        if self and self.localcontext and n.get('rml_loop', False):
+        if self and self.localcontext and n.get('rml_loop'):
             oldctx = self.localcontext
 
             for ctx in eval(n.get('rml_loop'),{}, self.localcontext):
@@ -77,12 +80,12 @@ def _child_get(node, self=None, tagname=None):
                         yield n
             self.localcontext = oldctx
             continue
-        if self and self.localcontext and n.get('rml_except', False):
+        if self and self.localcontext and n.get('rml_except'):
             try:
                 eval(n.get('rml_except'), {}, self.localcontext)
             except:
                 continue
-        if self and self.localcontext and n.get('rml_tag', False):
+        if self and self.localcontext and n.get('rml_tag'):
             try:
                 (tag,attr) = eval(n.get('rml_tag'),{}, self.localcontext)
                 n2 = copy.deepcopy(n)
@@ -104,24 +107,27 @@ def _process_text(self, txt):
         sps = _regex.split(txt)
         while sps:
             # This is a simple text to translate
-            result += self.localcontext.get('translate', lambda x:x)(sps.pop(0))
+            result += tools.ustr(self.localcontext.get('translate', lambda x:x)(sps.pop(0)))
             if sps:
                 try:
-                    txt = eval(sps.pop(0),self.localcontext)
-                except:
-                    pass
+                    expr = sps.pop(0)
+                    txt = eval(expr,self.localcontext)
+                    if txt and (isinstance(txt, unicode) or isinstance(txt, str)):
+                        txt = tools.ustr(self.localcontext.get('translate', lambda x:x)(txt))
+                except Exception,e:
+                    tb_s = reduce(lambda x, y: x+y, traceback.format_exception(sys.exc_type, sys.exc_value, sys.exc_traceback))
+                    netsvc.Logger().notifyChannel('report', netsvc.LOG_ERROR,
+                            'report :\n%s\n%s\nexpr: %s' % (tb_s, str(e),
+                                expr.encode('utf-8')))
                 if type(txt)==type('') or type(txt)==type(u''):
                     txt2 = str2xml(txt)
                     result += tools.ustr(txt2)
                 elif (txt is not None) and (txt is not False):
-                    result += str(txt)
+                    result += tools.ustr(txt)
         return result
 
 def text_get(node):
-    rc = ''
-    for node in node.getchildren():
-            rc = rc + tools.ustr(node.text)
-    return rc
+    return ''.join([tools.ustr(n.text) for n in node])
 
 units = [
     (re.compile('^(-?[0-9\.]+)\s*in$'), reportlab.lib.units.inch),
@@ -133,6 +139,15 @@ units = [
 def unit_get(size):
     global units
     if size:
+        if size.find('.') == -1:
+            decimal_point = '.'
+            try:
+                decimal_point = locale.nl_langinfo(locale.RADIXCHAR)
+            except:
+                decimal_point = locale.localeconv()['decimal_point']
+
+            size = size.replace(decimal_point, '.')
+
         for unit in units:
             res = unit[0].search(size, 0)
             if res:
@@ -142,8 +157,7 @@ def unit_get(size):
 def tuple_int_get(node, attr_name, default=None):
     if not node.get(attr_name):
         return default
-    res = [int(x) for x in node.get(attr_name).split(',')]
-    return res
+    return map(int, node.get(attr_name).split(','))
 
 def bool_get(value):
     return (str(value)=="1") or (value.lower()=='yes')
@@ -163,7 +177,7 @@ def attr_get(node, attrs, dict={}):
                 res[key] = int(node.get(key))
             elif dict[key]=='unit':
                 res[key] = unit_get(node.get(key))
-            elif dict[key] == 'float' : 
+            elif dict[key] == 'float' :
                 res[key] = float(node.get(key))
     return res
 
