@@ -24,7 +24,6 @@ import base64
 import logging
 import os
 import security
-import string
 import thread
 import threading
 import time
@@ -39,6 +38,8 @@ import release
 import sql_db
 import tools
 import locale
+from cStringIO import StringIO
+
 logging.basicConfig()
 
 class db(netsvc.Service):
@@ -62,6 +63,15 @@ class db(netsvc.Service):
 
         self._pg_psw_env_var_is_set = False # on win32, pg_dump need the PGPASSWORD env var
 
+    def _create_empty_database(self, name):
+        db = sql_db.db_connect('template1')
+        cr = db.cursor()
+        try:
+            cr.autocommit(True) # avoid transaction block
+            cr.execute("""CREATE DATABASE "%s" ENCODING 'unicode' TEMPLATE "template0" """ % name)
+        finally:
+            cr.close()
+
     def create(self, password, db_name, demo, lang, user_password='admin'):
         security.check_super(password)
         self.id_protect.acquire()
@@ -71,20 +81,13 @@ class db(netsvc.Service):
 
         self.actions[id] = {'clean': False}
 
-        db = sql_db.db_connect('template1')
-        cr = db.serialized_cursor()
-        try:
-            cr.autocommit(True) # XXX inhibit the effect of a serialized cursor. is it what we want ?
-            cr.execute('CREATE DATABASE "%s" ENCODING \'unicode\'' % db_name)
-        finally:
-            cr.close()
-            sql_db.close_db('template1')
+        self._create_empty_database(db_name)
+
         class DBInitialize(object):
             def __call__(self, serv, id, db_name, demo, lang, user_password='admin'):
                 cr = None
                 try:
                     serv.actions[id]['progress'] = 0
-                    clean = False
                     cr = sql_db.db_connect(db_name).cursor()
                     tools.init_db(cr)
                     cr.commit()
@@ -112,7 +115,6 @@ class db(netsvc.Service):
                 except Exception, e:
                     serv.actions[id]['clean'] = False
                     serv.actions[id]['exception'] = e
-                    from cStringIO import StringIO
                     import traceback
                     e_str = StringIO()
                     traceback.print_exc(file=e_str)
@@ -140,11 +142,11 @@ class db(netsvc.Service):
             clean = self.actions[id]['clean']
             if clean:
                 users = self.actions[id]['users']
-                del self.actions[id]
+                self.actions.pop(id)
                 return (1.0, users)
             else:
                 e = self.actions[id]['exception']
-                del self.actions[id]
+                self.actions.pop(id)
                 raise Exception, e
 
     def drop(self, password, db_name):
@@ -153,8 +155,8 @@ class db(netsvc.Service):
         logger = netsvc.Logger()
 
         db = sql_db.db_connect('template1')
-        cr = db.serialized_cursor()
-        cr.autocommit(True) # XXX inhibit the effect of a serialized cursor. is it what we want ?
+        cr = db.cursor()
+        cr.autocommit(True) # avoid transaction block
         try:
             try:
                 cr.execute('DROP DATABASE "%s"' % db_name)
@@ -166,9 +168,7 @@ class db(netsvc.Service):
                 logger.notifyChannel("web-services", netsvc.LOG_INFO,
                     'DROP DB: %s' % (db_name))
         finally:
-            cr.commit()
             cr.close()
-            sql_db.close_db('template1')
         return True
 
     def _set_pg_psw_env_var(self):
@@ -221,14 +221,7 @@ class db(netsvc.Service):
                     'RESTORE DB: %s already exists' % (db_name,))
             raise Exception, "Database already exists"
 
-        db = sql_db.db_connect('template1')
-        cr = db.serialized_cursor()
-        cr.autocommit(True) # XXX inhibit the effect of a serialized cursor. is it what we want ?
-        try:
-            cr.execute("""CREATE DATABASE "%s" ENCODING 'unicode' TEMPLATE "template0" """ % db_name)
-        finally:
-            cr.close()
-            sql_db.close_db('template1')
+        self._create_empty_database(db_name)
 
         cmd = ['pg_restore', '--no-owner']
         if tools.config['db_user']:
@@ -267,7 +260,8 @@ class db(netsvc.Service):
         logger = netsvc.Logger()
 
         db = sql_db.db_connect('template1')
-        cr = db.serialized_cursor()
+        cr = db.cursor()
+        cr.autocommit(True) # avoid transaction block
         try:
             try:
                 cr.execute('ALTER DATABASE "%s" RENAME TO "%s"' % (old_name, new_name))
@@ -283,19 +277,17 @@ class db(netsvc.Service):
                 logger.notifyChannel("web-services", netsvc.LOG_INFO,
                     'RENAME DB: %s -> %s' % (old_name, new_name))
         finally:
-            cr.commit()
             cr.close()
-            sql_db.close_db('template1')
         return True
 
     def db_exist(self, db_name):
-        try:
-            db = sql_db.db_connect(db_name)
-            return True
-        except:
-            return False
+        ## Not True: in fact, check if connection to database is possible. The database may exists
+        return bool(sql_db.db_connect(db_name))
+
+    def list(self, document=False):
+        if not tools.config['list_db'] and not document:
+            raise Exception('AccessDenied')
 
-    def list(self):
         db = sql_db.db_connect('template1')
         cr = db.cursor()
         try:
@@ -317,7 +309,6 @@ class db(netsvc.Service):
                 res = []
         finally:
             cr.close()
-            sql_db.close_db('template1')
         res.sort()
         return res
 
@@ -352,7 +343,7 @@ class db(netsvc.Service):
                 self.abortResponse(1, inst.name, 'warning', inst.value)
             except except_osv, inst:
                 self.abortResponse(1, inst.name, inst.exc_type, inst.value)
-            except Exception, e:
+            except Exception:
                 import traceback
                 tb_s = reduce(lambda x, y: x+y, traceback.format_exception( sys.exc_type, sys.exc_value, sys.exc_traceback))
                 l.notifyChannel('web-services', netsvc.LOG_ERROR, tb_s)
@@ -375,6 +366,7 @@ class common(netsvc.Service):
         self.exportMethod(self.get_migration_scripts)
         self.exportMethod(self.get_server_environment)
         self.exportMethod(self.login_message)
+        self.exportMethod(self.check_connectivity)
 
     def ir_set(self, db, uid, password, keys, args, name, value, replace=True, isobject=False):
         security.check(db, uid, password)
@@ -498,7 +490,7 @@ GNU Public Licence.
                         l.notifyChannel('migration', netsvc.LOG_ERROR, 'unable to read the module %s' % (module,))
                         raise
 
-                    zip_contents = cStringIO.StringIO(base64_decoded)
+                    zip_contents = StringIO(base64_decoded)
                     zip_contents.seek(0)
                     try:
                         try:
@@ -531,7 +523,7 @@ GNU Public Licence.
         try:
             rev_id = os.popen('bzr revision-info').read()
         except Exception,e:
-             rev_id = 'Exception: %s\n' % (tools.ustr(e))
+            rev_id = 'Exception: %s\n' % (tools.ustr(e))
 
         os_lang = '.'.join( [x for x in locale.getdefaultlocale() if x] )
         if not os_lang:
@@ -542,7 +534,7 @@ GNU Public Licence.
                      %(platform.platform(), platform.os.name)
         if os.name == 'posix':
           if platform.system() == 'Linux':
-             lsbinfo = os.popen('lsb_release -a').read()
+             lsbinfo = os.popen('lsb_release -idrc').read()
              environment += '%s'%(lsbinfo)
           else:
              environment += 'Your System is not lsb compliant\n'
@@ -556,11 +548,13 @@ GNU Public Licence.
                     %(platform.release(), platform.version(), platform.architecture()[0],
                       os_lang, platform.python_version(),release.version,rev_id)
         return environment
-    
 
     def login_message(self):
         return tools.config.get('login_message', False)
 
+    def check_connectivity(self):
+        return bool(sql_db.db_connect('template1'))
+
 common()
 
 class objects_proxy(netsvc.Service):
@@ -682,15 +676,19 @@ class report_spool(netsvc.Service):
 
         def go(id, uid, ids, datas, context):
             cr = pooler.get_db(db).cursor()
+            import traceback
+            import sys
             try:
                 obj = netsvc.LocalService('report.'+object)
                 (result, format) = obj.create(cr, uid, ids, datas, context)
+                if not result:
+                    tb = sys.exc_info()
+                    self._reports[id]['exception'] = ExceptionWithTraceback('RML is not available at specified location or not enough data to print!', tb)
                 self._reports[id]['result'] = result
                 self._reports[id]['format'] = format
                 self._reports[id]['state'] = True
             except Exception, exception:
-                import traceback
-                import sys
+                
                 tb = sys.exc_info()
                 tb_s = "".join(traceback.format_exception(*tb))
                 logger = netsvc.Logger()
