@@ -98,7 +98,7 @@ def init_db(cr):
                     values (%s, %s, %s, %s, %s, %s, %s, %s, %s)', (
                 id, info.get('author', ''),
                 info.get('website', ''), i, info.get('name', False),
-                info.get('description', ''), p_id, state, info.get('certificate')))
+                info.get('description', ''), p_id, state, info.get('certificate') or None))
             cr.execute('insert into ir_model_data \
                 (name,model,module, res_id, noupdate) values (%s,%s,%s,%s,%s)', (
                     'module_meta_information', 'ir.module.module', i, id, True))
@@ -527,9 +527,6 @@ class UpdateableDict(local):
     def __ge__(self, y):
         return self.dict.__ge__(y)
 
-    def __getitem__(self, y):
-        return self.dict.__getitem__(y)
-
     def __gt__(self, y):
         return self.dict.__gt__(y)
 
@@ -637,13 +634,13 @@ class cache(object):
             if *args and **kwargs are both empty, clear all the keys related to this database
         """
         if not args and not kwargs:
-            keys_to_del = [key for key in self.cache if key[0][1] == dbname]
+            keys_to_del = [key for key in self.cache.keys() if key[0][1] == dbname]
         else:
             kwargs2 = self._unify_args(*args, **kwargs)
-            keys_to_del = [key for key, _ in self._generate_keys(dbname, kwargs2) if key in self.cache]
+            keys_to_del = [key for key, _ in self._generate_keys(dbname, kwargs2) if key in self.cache.keys()]
         
         for key in keys_to_del:
-            del self.cache[key]
+            self.cache.pop(key)
     
     @classmethod
     def clean_caches_for_db(cls, dbname):
@@ -662,12 +659,12 @@ class cache(object):
             self.fun_default_values = dict(zip(self.fun_arg_names[-len(argspec[3]):], argspec[3]))
         
         def cached_result(self2, cr, *args, **kwargs):
-            if time.time()-self.timeout > self.lasttime:
+            if time.time()-int(self.timeout) > self.lasttime:
                 self.lasttime = time.time()
-                t = time.time()-self.timeout 
-                old_keys = [key for key in self.cache if self.cache[key][1] < t]
+                t = time.time()-int(self.timeout)
+                old_keys = [key for key in self.cache.keys() if self.cache[key][1] < t]
                 for key in old_keys:
-                    del self.cache[key]
+                    self.cache.pop(key)
 
             kwargs2 = self._unify_args(*args, **kwargs)
 
@@ -704,6 +701,22 @@ class cache(object):
 def to_xml(s):
     return s.replace('&','&amp;').replace('<','&lt;').replace('>','&gt;')
 
+def get_encodings():
+    yield 'utf8'
+    from locale import getpreferredencoding
+    prefenc = getpreferredencoding()
+    if prefenc:
+        yield prefenc
+
+        prefenc = {
+            'latin1': 'latin9',
+            'iso-8859-1': 'iso8859-15',
+            'cp1252': '1252',
+        }.get(prefenc.lower())
+        if prefenc:
+            yield prefenc
+
+
 def ustr(value):
     """This method is similar to the builtin `str` method, except
     it will return Unicode string.
@@ -713,29 +726,25 @@ def ustr(value):
     @rtype: unicode
     @return: unicode string
     """
+    orig = value
+    if isinstance(value, Exception):
+        return exception_to_unicode(value)
 
     if isinstance(value, unicode):
         return value
 
-    if hasattr(value, '__unicode__'):
+    try:
         return unicode(value)
-
-    if not isinstance(value, str):
-        value = str(value)
-
-    try: # first try utf-8
-        return unicode(value, 'utf-8')
     except:
         pass
 
-    try: # then extened iso-8858
-        return unicode(value, 'iso-8859-15')
-    except:
-        pass
+    for ln in get_encodings():
+        try:
+            return unicode(value, ln)
+        except:
+            pass
+    raise UnicodeError('unable de to convert %r' % (orig,))
 
-    # else use default system locale
-    from locale import getlocale
-    return unicode(value, getlocale()[1])
 
 def exception_to_unicode(e):
     if hasattr(e, 'message'):
@@ -789,14 +798,17 @@ def get_languages():
         'es_ES': u'Spanish / Español',
         'et_EE': u'Estonian / Eesti keel',
         'fi_FI': u'Finland / Suomi',
+        'fa_IR': u'Persian / فارس',
         'fr_BE': u'French (BE) / Français (BE)',
         'fr_CH': u'French (CH) / Français (CH)',
         'fr_FR': u'French / Français',
+        'gl_ES': u'Galician / Galego',
         'hr_HR': u'Croatian / hrvatski jezik',
         'hu_HU': u'Hungarian / Magyar',
         'id_ID': u'Indonesian / Bahasa Indonesia',
         'it_IT': u'Italian / Italiano',
         'lt_LT': u'Lithuanian / Lietuvių kalba',
+        'lv_LV': u'Latvian / Latviešu valoda',
         'nl_NL': u'Dutch / Nederlands',
         'nl_BE': u'Dutch (Belgium) / Nederlands (Belgïe)',
         'pl_PL': u'Polish / Język polski',
@@ -804,7 +816,8 @@ def get_languages():
         'pt_PT': u'Portugese / português',
         'ro_RO': u'Romanian / limba română',
         'ru_RU': u'Russian / русский язык',
-        'sl_SL': u'Slovenian / slovenščina',
+        'sl_SI': u'Slovenian / slovenščina',
+        'sk_SK': u'Slovak Language / Slovenský jazyk',
         'sq_AL': u'Albanian / Shqipëri',
         'sv_SE': u'Swedish / svenska',
         'tr_TR': u'Turkish / Türkçe',
@@ -826,17 +839,19 @@ def scan_languages():
 
 
 def get_user_companies(cr, user):
+    # FIXME: use orm !
     def _get_company_children(cr, ids):
         if not ids:
             return []
-        cr.execute('SELECT id FROM res_company WHERE parent_id = any(array[%s])' %(','.join([str(x) for x in ids]),))
-        res=[x[0] for x in cr.fetchall()]
+        cr.execute('SELECT id FROM res_company WHERE parent_id IN %s', (tuple(ids),))
+        res = [x[0] for x in cr.fetchall()]
         res.extend(_get_company_children(cr, res))
         return res
-    cr.execute('SELECT comp.id FROM res_company AS comp, res_users AS u WHERE u.id = %s AND comp.id = u.company_id' % (user,))
-    compids=[cr.fetchone()[0]]
-    compids.extend(_get_company_children(cr, compids))
-    return compids
+    cr.execute('SELECT company_id FROM res_users WHERE id=%s', (user,))
+    user_comp = cr.fetchone()[0]
+    if not user_comp:
+        return []
+    return [user_comp] + _get_company_children(cr, [user_comp])
 
 def mod10r(number):
     """
