@@ -23,9 +23,9 @@
 import os
 from os.path import join
 import fnmatch
-import csv, xml.dom, re
+import csv, re
+from lxml import etree
 import tools, pooler
-from osv.orm import BrowseRecordError
 import ir
 import netsvc
 from tools.misc import UpdateableStr
@@ -132,10 +132,18 @@ class GettextAlias(object):
 
         cr = frame.f_locals.get('cr')
         lang = (frame.f_locals.get('context') or {}).get('lang', False)
+        
+        if not (cr and lang):
+            args = frame.f_locals.get('args',False)
+            if args:
+                lang = args[-1].get('lang',False)
+                if frame.f_globals.get('pooler',False):
+                    cr = pooler.get_db(frame.f_globals['pooler'].pool_dic.keys()[0]).cursor()
+        
         if not (lang and cr):
             return source
 
-        cr.execute('select value from ir_translation where lang=%s and type=%s and src=%s', (lang, 'code', source))
+        cr.execute('select value from ir_translation where lang=%s and type in (%s,%s) and src=%s', (lang, 'code','sql_constraint', source))
         res_trans = cr.fetchone()
         return res_trans and res_trans[0] or source
 _ = GettextAlias()
@@ -144,8 +152,12 @@ _ = GettextAlias()
 # class to handle po files
 class TinyPoFile(object):
     def __init__(self, buffer):
+        self.logger = netsvc.Logger()
         self.buffer = buffer
 
+    def warn(self, msg):
+        self.logger.notifyChannel("i18n", netsvc.LOG_WARNING, msg)
+
     def __iter__(self):
         self.buffer.seek(0)
         self.lines = self._get_lines()
@@ -180,7 +192,12 @@ class TinyPoFile(object):
                     raise StopIteration()
                 line = self.lines.pop(0).strip()
                 if line.startswith('#:'): 
-                    tmp_tnrs.append( line[2:].strip().split(':') )
+                    for item in line[2:].strip().split(' '):
+                        value = item.split(':')
+                        if len(value) == 3:
+                            if value[2].endswith(','):
+                                value[2] = value[2][:-1]
+                            tmp_tnrs.append( value )
                 if line.startswith('#'):
                     line = None
 
@@ -215,6 +232,10 @@ class TinyPoFile(object):
                     self.tnrs.append((t, n, r, source, trad))
 
         self.first = False
+
+        if name is None:
+            self.warn('Missing "#:" formated comment for the following source:\n\t%s' % (source,))
+            return self.next()
         return type, name, res_id, source, trad
 
     def write_infos(self, modules):
@@ -335,10 +356,10 @@ def trans_export(lang, modules, buffer, format, dbname=None):
 
 def trans_parse_xsl(de):
     res = []
-    for n in [i for i in de.childNodes if (i.nodeType == i.ELEMENT_NODE)]:
-        if n.hasAttribute("t"):
-            for m in [j for j in n.childNodes if (j.nodeType == j.TEXT_NODE)]:
-                l = m.data.strip().replace('\n',' ')
+    for n in de:
+        if n.get("t"):
+            for m in [j for j in n if j.text]:
+                l = m.text.strip().replace('\n',' ')
                 if len(l):
                     res.append(l.encode("utf8"))
         res.extend(trans_parse_xsl(n))
@@ -346,9 +367,9 @@ def trans_parse_xsl(de):
 
 def trans_parse_rml(de):
     res = []
-    for n in [i for i in de.childNodes if (i.nodeType == i.ELEMENT_NODE)]:
-        for m in [j for j in n.childNodes if (j.nodeType == j.TEXT_NODE)]:
-            string_list = [s.replace('\n', ' ').strip() for s in re.split('\[\[.+?\]\]', m.data)]
+    for n in de:
+        for m in [j for j in n if j.text]:
+            string_list = [s.replace('\n', ' ').strip() for s in re.split('\[\[.+?\]\]', m.text)]
             for s in string_list:
                 if s:
                     res.append(s.encode("utf8"))
@@ -357,15 +378,11 @@ def trans_parse_rml(de):
 
 def trans_parse_view(de):
     res = []
-    if de.hasAttribute("string"):
-        s = de.getAttribute('string')
-        if s:
-            res.append(s.encode("utf8"))
-    if de.hasAttribute("sum"):
-        s = de.getAttribute('sum')
-        if s:
-            res.append(s.encode("utf8"))
-    for n in [i for i in de.childNodes if (i.nodeType == i.ELEMENT_NODE)]:
+    if de.get("string"):
+        res.append(de.get('string').encode("utf8"))
+    if de.get("sum"):
+        res.append(de.get('sum').encode("utf8"))
+    for n in de:
         res.extend(trans_parse_view(n))
     return res
 
@@ -400,11 +417,12 @@ def trans_generate(lang, modules, dbname=None):
 
     query = 'SELECT name, model, res_id, module'    \
             '  FROM ir_model_data'
-    if not 'all' in modules:
-        query += ' WHERE module IN (%s)' % ','.join(['%s']*len(modules))
+    query_param = None
+    if 'all' not in modules:
+        query += ' WHERE module IN %s'
+        query_param = (tuple(modules),)
     query += ' ORDER BY module, model, name'
 
-    query_param = not 'all' in modules and modules or None
     cr.execute(query, query_param)
 
     _to_translate = []
@@ -424,18 +442,18 @@ def trans_generate(lang, modules, dbname=None):
         xml_name = "%s.%s" % (module, encode(xml_name))
 
         if not pool.get(model):
-            logger.notifyChannel("db", netsvc.LOG_ERROR, "unable to find object %r" % (model,))
+            logger.notifyChannel("db", netsvc.LOG_ERROR, "Unable to find object %r" % (model,))
             continue
         
-        try:
-            obj = pool.get(model).browse(cr, uid, res_id)
-        except BrowseRecordError:
-            logger.notifyChannel("db", netsvc.LOG_ERROR, "unable to find object %r with id %d" % (model, res_id))
+        exists = pool.get(model).exists(cr, uid, res_id)
+        if not exists:
+            logger.notifyChannel("db", netsvc.LOG_WARNING, "Unable to find object %r with id %d" % (model, res_id))
             continue
+        obj = pool.get(model).browse(cr, uid, res_id)
 
         if model=='ir.ui.view':
-            d = xml.dom.minidom.parseString(encode(obj.arch))
-            for t in trans_parse_view(d.documentElement):
+            d = etree.XML(encode(obj.arch))
+            for t in trans_parse_view(d):
                 push_translation(module, 'view', encode(obj.model), 0, t)
         elif model=='ir.actions.wizard':
             service_name = 'wizard.'+encode(obj.wiz_name)
@@ -467,8 +485,8 @@ def trans_generate(lang, modules, dbname=None):
                         # export arch
                         arch = result['arch']
                         if arch and not isinstance(arch, UpdateableStr):
-                            d = xml.dom.minidom.parseString(arch)
-                            for t in trans_parse_view(d.documentElement):
+                            d = etree.XML(arch)
+                            for t in trans_parse_view(d):
                                 push_translation(module, 'wizard_view', name, 0, t)
 
                         # export button labels
@@ -522,10 +540,10 @@ def trans_generate(lang, modules, dbname=None):
                 report_type = "xsl"
             try:
                 xmlstr = tools.file_open(fname).read()
-                d = xml.dom.minidom.parseString(xmlstr)
-                for t in parse_func(d.documentElement):
+                d = etree.XML(xmlstr)
+                for t in parse_func(d):
                     push_translation(module, report_type, name, 0, t)
-            except IOError, xml.dom.expatbuilder.expat.ExpatError:
+            except IOError, etree.XMLSyntaxError:
                 if fname:
                     logger.notifyChannel("i18n", netsvc.LOG_ERROR, "couldn't export translation for report %s %s %s" % (name, report_type, fname))
 
@@ -541,10 +559,14 @@ def trans_generate(lang, modules, dbname=None):
 
     # parse source code for _() calls
     def get_module_from_path(path):
-        relative_addons_path = tools.config['addons_path'][len(tools.config['root_path'])+1:]
-        if path.startswith(relative_addons_path) and (os.path.dirname(path) != relative_addons_path):
-            path = path[len(relative_addons_path)+1:]
-            return path.split(os.path.sep)[0]
+        path_dir = os.path.dirname(path[1:])
+        if path_dir:
+            if os.path.exists(os.path.join(tools.config['addons_path'],path[1:])):
+                return path.split(os.path.sep)[1]
+            else:
+                root_addons = os.path.join(tools.config['root_path'], 'addons')
+                if os.path.exists(os.path.join(root_addons,path[1:])):
+                    return path.split(os.path.sep)[1]
         return 'base'   # files that are not in a module are considered as being in 'base' module
 
     modobj = pool.get('ir.module.module')
@@ -552,13 +574,13 @@ def trans_generate(lang, modules, dbname=None):
     installed_modules = map(lambda m: m['name'], modobj.read(cr, uid, installed_modids, ['name']))
     
     root_path = os.path.join(tools.config['root_path'], 'addons')
-
+    
     if root_path in tools.config['addons_path'] :
         path_list = [root_path]
     else :
         path_list = [root_path,tools.config['addons_path']]
 
-    for path in path_list: 
+    for path in path_list:
         for root, dirs, files in tools.osutil.walksymlinks(path):
             for fname in fnmatch.filter(files, '*.py'):
                 fabsolutepath = join(root, fname)
@@ -611,7 +633,7 @@ def trans_load_data(db_name, fileobj, fileformat, lang, strict=False, lang_name=
         uid = 1
         cr = pooler.get_db(db_name).cursor()
         ids = lang_obj.search(cr, uid, [('code','=', lang)])
-        
+
         if not ids:
             # lets create the language with locale information
             fail = True
@@ -625,22 +647,27 @@ def trans_load_data(db_name, fileobj, fileformat, lang, strict=False, lang_name=
             if fail:
                 lc = locale.getdefaultlocale()[0]
                 msg = 'Unable to get information for locale %s. Information from the default locale (%s) have been used.'
-                logger.notifyChannel('i18n', netsvc.LOG_WARNING, msg % (lang, lc)) 
-                
+                logger.notifyChannel('i18n', netsvc.LOG_WARNING, msg % (lang, lc))
+
             if not lang_name:
                 lang_name = tools.get_languages().get(lang, lang)
-            
+
+            def fix_xa0(s):
+                if s == '\xa0':
+                    return '\xc2\xa0'
+                return s
+
             lang_info = {
                 'code': lang,
                 'name': lang_name,
                 'translatable': 1,
                 'date_format' : str(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')),
                 'time_format' : str(locale.nl_langinfo(locale.T_FMT)),
-                'decimal_point' : str(locale.localeconv()['decimal_point']).replace('\xa0', '\xc2\xa0'),
-                'thousands_sep' : str(locale.localeconv()['thousands_sep']).replace('\xa0', '\xc2\xa0'),
+                'decimal_point' : fix_xa0(str(locale.localeconv()['decimal_point'])),
+                'thousands_sep' : fix_xa0(str(locale.localeconv()['thousands_sep'])),
             }
-            
-            try: 
+
+            try:
                 lang_obj.create(cr, uid, lang_info)
             finally:
                 resetlocale()
@@ -698,6 +725,8 @@ def trans_load_data(db_name, fileobj, fileformat, lang, strict=False, lang_name=
                 # the same source
                 obj = pool.get(model)
                 if obj:
+                    if field not in obj.fields_get_keys(cr, uid):
+                        continue
                     ids = obj.search(cr, uid, [(field, '=', dic['src'])])
 
                     # if the resource id (res_id) is in that list, use it,
